/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

*** WDR settings
	include wdrsettings

/*******************************************************************************
PREPARE DATA
*******************************************************************************/

*** import data
	use "${data}/OECD 2016 Chile", clear
	
***	archive data
	wdrarchive
		
/*******************************************************************************
GRAPH
*******************************************************************************/

***	set options
	local lopts m(O) c(l) lw(medthick) msize(medlarge)
	sum year
	local maxyear=`r(max)'
	local xcoord=`maxyear'+.5
	sum chile_reading if year==`maxyear'
	local ycoord =`r(mean)'+5
	local labels `labels' text(`ycoord' `xcoord' "Chile", color("$wdrscheme2") placement(e))
	sum oecd_reading if year==`maxyear'
	local ycoord =`r(mean)'-2
	local labels `labels' text(`ycoord' `xcoord' "OECD", color("$wdrscheme1") placement(e))
	local gopts graphregion(c(white)lc(white)lw(thick)margin(r+5)) ///
		plotregion(margin(l+5 r+5 b+1)) ///	
		ylabel(, angle(h) glc(gs2) glw(thin) glp(shortdash) notick labgap(2)) ///
		yscale(noline) ///
		xscale(noline) ///
		legend(off)

***	graph
	twoway ///
	(scatter chile_reading year	, `lopts' lc("$wdrscheme2") mc("$wdrscheme2")) ///
	(scatter oecd_reading year	, `lopts' lc("$wdrscheme1") mc("$wdrscheme1")) ///
		, ///
	`labels' ///
	`gopts' ///
	xtitle("Year", margin(t+3)) ///
	ytitle("Score") ///
	scale(1.5) ///
	xsize(4) ysize(3)
	
/*******************************************************************************
EXPORT
*******************************************************************************/

wdrexport , ///
	title(Reading scores have improved in Chile) ///
	subtitle(PISA reading scores (2000-2015)) ///
	source(WDR 2018 team, using data from the Programme for International Student Assessment, (PISA) (www.oecd.org/pisa).) ///
	note(OECD = Organisation for Economic Co-operation and Development.) ///
	chapter(11) figure(5.1) box
	
exit
