/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings

/*******************************************************************************
PREP DATA
*******************************************************************************/

***	load data
	use "${data}/Barro Lee 2013 and TIMSS 2015 quality adjusted schooling", clear

***	archive data
	wdrarchive
	
/*******************************************************************************
GRAPH
*******************************************************************************/

***	set options
	local tsize medium

***	graph
	graph bar  actualyrs adjustedyrs, ///
		over(country, sort(country)   label(angle(45))) /// adjustedyrs des
		graphregion(c(white)lc(white)lw(thick)m(t-5 b-5 r-2)) ///
		plotregion(m(l-1 r-1)) ///
		ylabels(0(3)15, angle(horizontal) notick glc(gs12) glp(solid) glw(thin) labsize(`tsize') ) ///
		ytitle("Years of schooling", size(`tsize')) ///
		yscale(noline ) ///
		bargap(-100) ///
		nofill ///
		legend( ///
			region(c(none)margin(t-5)) ///
			bexpand ///
			symx(3) symy(3) ///
			label(2 "Quality-adjusted years") ///
			label(1 "Actual years") ///
			size(`tsize') ///
			 ///
			) ///
		bar(2 , col("$wdrscheme1") lw(medthick)) ///
		bar(1 , lc("$wdrscheme1") fc(white) lw(medthick)) ///
		xsize(6.5) ysize(3)

/*******************************************************************************
EXPORT
*******************************************************************************/		

wdrexport , ///
	title(There can be a large gap between learning-adjusted and unadjusted years of schooling) ///
	subtitle(Years of actual and learning-adjusted schooling among young people, ages 25–29, illustrated using TIMSS data) ///
	source(WDR 2018 team, using data from Barro and Lee (2013) and Trends in International Mathematics and Science Study (TIMSS), 2015 (Mullis and others 2016).)  ///
	note(Years of schooling in Singapore are the same as learning-adjusted years because Singapore, which scored highest on the TIMSS mathematics assessment in 2015, serves as the basis for comparison in this illustration.) ///
	chapter(1) figure(3.1) box
		
exit

