/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
Box Figure 3.2.1 Girls outperform boys on reading in all countries, but boys 
do slightly better in mathematics and science
*******************************************************************************/
	
*** WDR settings
	include wdrsettings

/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	load data
	use "${data}/PISA 2015 gender differences", clear
	preserve
	bysort country: gen countervar=1 if _n==1
	tab country, sum(countervar)
	restore
	
***	keep only obs we want
	* keep if subject=="mathematics"
	keep if stat=="Score"
	keep if gender !="Difference"
	keep if ptile=="Mean" 
	drop stat ptile

***	reshape data
	reshape wide score, i(country  subject year) j(gender) str
	reshape wide score*, i(country subject) j(year) 
	reshape wide score*, i(country) j(subject) str
rename score* *
rename _all, lower
***	calculate gaps
	foreach year in 2003 2009 2015 {
		foreach subject in reading mathematics science {
		gen gap`year'`subject' = girls`year'`subject'-boys`year'`subject' if (girls`year'`subject'!=. & boys`year'`subject'!=.)
		}
		}

***	trim and label data
	keep country gap2015*
	lab var country "Country"
	lab var gap2015reading 		"PISA 2015 gender gap in country means for reading (girls-boys)"
	lab var gap2015mathematics 	"PISA 2015 gender gap in country means for mathematics (girls-boys)"
	lab var gap2015science 		"PISA 2015 gender gap in country means for science (girls-boys)"

***	archive data
	wdrarchive
	
/*******************************************************************************
GRAPH
*******************************************************************************/

***	set graph options
	local lopts lw(thick) 
	local textsize small
	local lgopts region(c(none)margin(t-2))
	local gopts	graphregion(c(white)lc(white)lw(thick)margin(t+4 b-5)) ylabel(none,nogrid angle(h)) ///
		xtitle("Average gender gap, by country (Girls-Boys)", size(`textsize')) ///
		ytitle("Density of gender gaps", size(`textsize'))  ///
		xline(0, lw(thin) lc(black) lp(shortdash)) 

***	GRAPH DENSITIES FOR ALL SUBJECT
	twoway ///
		(kdensity gap2015mathematics, 	`lopts' lc("${wdrscheme6}") ) ///
		(kdensity gap2015reading, 		`lopts' lc("${wdrscheme3}")) ///
		(kdensity gap2015science, 		`lopts' lc("${wdrscheme1}")) ///
		, ///
		`gopts' ///
		text(.039 -29 "{it:Overall, boys slightly outperform}" "{it:girls in mathematics and}" "{it:science}", color("$wdrscheme1") size(`textsize') just(left) placement(e)) ///
		text(.033 30 	"{it:Girls outperform boys in}" ///
						"{it:reading by a substantial}" ///
						"{it:margin in every country}", color("$wdrscheme3") size(`textsize') just(left) placement(e)) ///
		legend( `lgopts' ///
			label(1 "Mathematics") ///
			label(2 "Reading") ///
			label(3 "Science") ///
			r(1) ///
			symx(4) symy(4) ///
			order(1 3 2) ///
			size(`textsize') ///
			 ///
			) ///
		xsize(6.5) ysize(3) ///
			xlabel(-30(10)70, labsize(`textsize')) ///
		scale(1.35) ///
		name(density, replace) 

/*******************************************************************************
EXPORT
*******************************************************************************/

	wdrexport , ///
		title(Girls outperform boys on reading in all countries, but boys typically do better in mathematics and science) ///
		subtitle(Distribution across countries of gap between mean score for girls and mean score for boys) ///
		source(WDR 2018 team, using data from Programme for International Student Assessment (PISA) collected in 2015 (OECD 2016a).) ///
		note(Distribution based on pooled data from 72 countries.) ///
		chapter(3) figure(2.1) box
		
exit

		
