/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	load data
	use "${data}/Sabarwal Abu-Jawdeh and Masood 2017", clear

***	set locals
	local themes 	help attention absence
	local help 		q_5d q_5e
	local attention q_2g q_2h
	local absence 	q_10a q_10b q_10c
	
***	review stats
	foreach theme of local themes {
		foreach var of local `theme' {
			local `var'lbl : var label `var'
			local `var'lbl =subinstr("``var'lbl'","Acceptable absence: ","",1)
			local `var'lbl =subinstr("``var'lbl'","Students deserve attention: ","",1)
			local `var'lbl =subinstr("``var'lbl'","Can't help: ","",1)
			local `var'lbl =subinstr("``var'lbl'","do in absence","do",1)
			local `var'lbl =subinstr("``var'lbl'","Doing","Do",1)
			local `var'lbl =subinstr("``var'lbl'","assigned","the assigned",1)
			local `var'lbl =subinstr("``var'lbl'","Perform","Are performing",1)
			local `var'lbl =subinstr("``var'lbl'","Lagging behind","Are lagging behind in class",1)
			local `var'lbl =subinstr("``var'lbl'","personal/financial","personal or financial",1)
			local `var'lbl =subinstr("``var'lbl'","Parents do","Do",1)
			local `var'lbl =subinstr("``var'lbl'","Parents have","Have",1)
			noi di as result _newline "``var'lbl'" _c
			tab `var'
			}
			}
	
***	collapse data
	ds country, not
	local allvars `r(varlist)'
	collapse `allvars', by(country)
	foreach var of local allvars {
		replace `var'=100*`var'
		label var `var' "``var'lbl'"
		}
	
***	generate sort vars
	foreach theme of local themes {
		egen sort_`theme'=rowmean(``theme'')
		lab var sort_`theme' "Sort variable for `theme' theme"
		}

***	format data
	format `allvars' %3.0f
	
/*******************************************************************************
GRAPH
*******************************************************************************/

***	set titles, etc
	local tsize small
	local absence_legtitle 		"It is acceptable for teachers to be absent if they"
	local attention_legtitle 	"Students deserve more attention if they"
	local help_legtitle			"There is little teachers can do if parents"
	local help_ttl 				"a. Do teachers think they can" "    help poor children learn?"
	local help_panel 			"Do teachers think they can help poor children learn?" 
	local attention_ttl 		"b. Do teachers believe children who lag" "    behind deserve additional effort?"
	local attention_panel 		"Do teachers believe children who lag behind deserve additional effort?"
	local absence_ttl 			"c. Do teachers believe their" "    absence is acceptable?"
	local absence_panel 		"Do teachers believe their absence is acceptable?"
	
foreach theme of local themes {
	local i=0
	foreach var of local `theme' {
		local ++i
		local lbl`i' : var label `var'
		}

	graph bar ``theme'', ///
		over(country, sort(sort_`theme') des label(labsize(`tsize') angle(45))) ///
		legend( ///
			rowgap(*.5) ///
			height(15) ///
			region(c(none)margin(l-3)) symx(2) symy(2) c(1) size(`tsize') pos(6) ///
			label(1 "`lbl1'") label(2 "`lbl2'") label(3 "`lbl3'") ///
			title("``theme'_legtitle'", size(`tsize') color(black) bexpand just(left)) ///
			) ///
		 title("``theme'_ttl'", bexpand just(left) color(black) size(small)) ///
		 bar(1, color($wdrscheme3)) bar(2, color($wdrscheme1)) bar(3, color($wdrscheme2)) ///
		 ylabels(0(20)100,angle(horizontal) notick glc(gs8) glw(vthin) labsize(`tsize') glp(shortdash)) ///
		 graphregion(c(white)lc(white)lw(thick)margin(l-4 r-3 t-5 b-5)) ///
		 yscale(range(0 100) noline) ///
		 ytitle("% of teachers who agree", size(`tsize') color(black) margin(r-1)) ///
		 xsize(3.5) ysize(2.5) ///
		name(`theme'_bar, replace)
		}

***	combine graphs

graph combine help_bar  attention_bar absence_bar, r(1) xsize(6.5) ysize(2.5) imargin(3 0 0 0) graphregion(c(white)lc(white)lw(thick)) ycommon scale(1.65)

/*******************************************************************************
EXPORT
*******************************************************************************/

***	archive data
	foreach theme of local themes {
		preserve
		keep country ``theme''
		wdrarchive, title(``theme'_panel')
		restore
		}

***	export graph
	wdrexport, ///
		title(Teachers may think a less than full effort is justified) ///
		source(Sabarwal, Abu-Jawdeh, and Masood 2017) ///
		note(Responses are not mutually exclusive. Data are from public schools, except for Senegal (private and public schools) and Uganda (private schools).) ///
	chapter(3) figure(3.1) box 

exit
