/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

*** start up commands
	version 14
	set seed 1000
	qui cap log c
	set more off
	set linesize 120
	set more off
	graph drop _all

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	import data
	use "${data}/Ethnologue 2015", clear

***	archive data
	wdrarchive
	
***	merge with map ids
	merge 1:1 country using "${data}/map_country_ids", keep(3 2) nogen
	
/*******************************************************************************
GRAPH
*******************************************************************************/

spmap index using "${data}/map_coordinates.dta" if country !="Antarctica" , ///
	id(country_id) ///
	fcolor(Blues2) ///
	ndf(white) ///
	ndo(black) ///
	clm(q) cln(10) ///
	legend( on ///
		order(2 3 4 5 6 7 8 9 10 11) ///
		r(1) size(4) ///
		colgap(0) ///
		symx(4) symy(4) ///
		title("Probability two randomly" "selected individuals speak" "a different language:" " " "Low                      High", bexpand just(left)) ///
		label(1 "") label(2 "") label(3 "") label(4 "") label(5 "") label(6 "") label(7 "") label(8 "") label(9 "") label(10 "") label(11 "") ///
	) ///
	legstyle(2) 
	
/*******************************************************************************
EXPORT
*******************************************************************************/

wdrexport, ///
	title(Mother-tongue instruction could be useful in much of the developing world) ///
	subtitle(Linguistic diversity, by country) ///
	source(WDR 2018 team, using data from Ethnologue (2015).) ///
	chapter(6) figure(3.1) box
