/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	import data
	use "${data}/TIMSS 1995-2005 England", clear

***	archive data
	
	*** panel 1
		preserve
		keep year england_average world_average oecd_average
		wdrarchive
		restore
		
	***	panel 2
		preserve
		keep year above_intermediate below_intermediate
		wdrarchive
		restore
		
***	tempfile
	tempfile working
	save `working'

/*******************************************************************************
GRAPH
*******************************************************************************/

***	set graph options
	local lopts c(l) m(none) lw(thick)
	sum year
	local maxyear=`r(max)'
	local xcoord =`maxyear'+2

***	set labels for panel a
	sum england_average if year==`maxyear' 
	local labelsa 			text(`r(mean)' `xcoord' "England", placement(e) just(left))
	sum oecd_average  if year==`maxyear' 
	local labelsa `labelsa' text(`r(mean)' `xcoord' "OECD" , placement(e) just(left))
	sum world_average  if year==`maxyear' 
	local labelsa `labelsa' text(`r(mean)' `xcoord' "All participating" "countries", placement(e) just(left))

***	set labels for panel b
	sum above_intermediate if year==`maxyear'
	local labelsb 			text(`r(mean)' `xcoord' "Above" "intermediate", placement(e) just(left))
	sum below_intermediate if year==`maxyear'
	local labelsb `labelsb'	text(`r(mean)' `xcoord' "Below" "intermediate", placement(e) just(left))
	
***	set options
	local gopts legend(off) ///
		ylabel(#5, notick angle(h) glc(gs2) glw(thin) glp(shortdash) labgap(1)) ///
		xscale(noline) ///
		xtitle("Year", margin(t+1)) ///
		graphregion(c(white)lc(white)lw(thick)margin(r+28)) 
	local titopts bexpand just(left) color(black) size(medsmall) margin(b+3 l-5)

***	graph panel 1
	twoway ///
	(scatter england_average year	, lc("$wdrscheme1") `lopts') ///
	(scatter oecd_average year		, lc("$wdrscheme3") `lopts') ///
	(scatter world_average year		, lc("$wdrscheme2") `lopts') ///
		, ///
	`labelsa' ///
	`gopts' ///
	title("{bf:a. Average scores for grade 4 students}" " ", `titopts') ///
	ytitle(Score) ///
	yscale(noline) ///
	name(panela)
	
***	graph panel 2
	twoway ///
	(scatter above_intermediate  year	, lc("$wdrscheme1") `lopts') ///
	(scatter below_intermediate year	, lc("$wdrscheme2") `lopts') ///
		, ///
	`labelsb' ///
	`gopts' ///
	title("{bf:b. Students above and below the}" "{bf:    intermediate benchmark, England}", `titopts') ///
	ytitle(Percent) ///
	yscale(range(0 50) noline) ///
	name(panelb)
		
***	combine
	graph combine panela panelb, graphregion(c(white)lc(white)lw(thick)margin(r-16 l-5 t-5 b-5)) name(combo)
	graph draw combo, xsize(6.5) ysize(2.75) scale(1.85)
	graph drop panela panelb

/*******************************************************************************
EXPORT
*******************************************************************************/
	
	wdrexport , ///
		title(Primary school numeracy has increased dramatically in England) ///
		subtitle(TIMSS scores for grade 4 students (1995-2015)) ///
		source(WDR 2018 team, using data from  Trends in International Mathematics and Science Study (TIMSS), 1995-2015 (timssandpirls.bc.edu/).) ///
		note(Students at the intermediate level can apply basic mathematical knowledge in straightforward situations; demonstrate an understanding of whole numbers and some understanding of fractions; visualize three-dimensional shapes from two-dimensional representations; and interpret bar graphs, pictographs, and tables to solve simple problems. OECD =  Organisation for Economic Co-operation and Development.) ///
		chapter(11) figure(1)

exit
