/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREP DATA
*******************************************************************************/

*** import data 
	use "${data}/Ansell 2010 Philippines political trends", clear

***	archive data
	wdrarchive
	
/*******************************************************************************
GRAPH
*******************************************************************************/

***	set options
	local lopts c(l) m(none) lw(thick)
	local gopts graphregion(c(white)lc(white)lw(thick)) ///
			ylabel(, nogrid angle(h) axis(2)) ///
			ylabel(, nogrid angle(h) axis(1)) ///
			legend(region(c(none)) c(1) symx(4) symy(4))
	local titopts bexpand just(left) color(black) size(medsmall)
	
	
		twoway ///
		(scatter pubed 	 year if year<1960, `lopts'  lc("$wdrscheme1") ) ///
		(scatter polity2 year if year<1960, `lopts' lc("$wdrscheme2") ) ///
		(scatter invpctacfe year if year<1960, `lopts' lc("$wdrscheme3") ) ///
			, ///
				yscale(noline) xscale(noline) ylabel(none) xlabel(none) xtitle("") ytitle("") ///
				graphregion(c(white)lc(white)lw(thick)) ///
				legend(region(c(none)) r(1) symx(4) symy(4)) ///
				fysize(0) fxsize(0) name(combined_legend, replace)
		
***	education spending and polity score
	twoway ///
		(scatter pubed 	 year, `lopts' yaxis(1) lc("$wdrscheme1") ) ///
		(scatter polity2 year, `lopts' yaxis(2) lc("$wdrscheme2") ) ///
		  , ///
		  ytitle("Public education spending" "(% of GDP)", axis(1) margin(r+2)) ///
		  `gopts' ///
		  title("{bf:a. Spending and governance}", `titopts') ///
		  name(panela, replace)
	
***	education spending and trade openness
	twoway ///
		(scatter pubed 	 year, `lopts' yaxis(1) lc("$wdrscheme1") ) ///
		(scatter invpctacfe year, `lopts' yaxis(2) lc("$wdrscheme3") ) ///
		  , ///
		  ytitle("Public education spending" "(% of GDP)", axis(1) margin(r+1)) ///
		  `gopts' ///
		  title("{bf:b. Spending and trade openness}", `titopts') ///
		  name(panelb, replace)
		  
		  
***	combine
	grc1leg combined_legend panela panelb, r(1) imargin(5 4 0 0) graphregion(c(white)lc(white)lw(thick)margin(l-20 r-8)) iscale(1.05) name(combograph, replace)
	graph draw combograph, xsize(6.5) ysize(2.75) scale(1.3)
	graph drop panela panelb
	
/*******************************************************************************
EXPORT
*******************************************************************************/
	
	wdrexport , ///
		title(Trends in public education spending in the Philippines are associated with changes in the broader political and economic context) ///
		subtitle(Public education spending as percentage of GDP and measures of democracy and trade openness, the Philippines (1960-2000)) ///
		note(Level of democracy is measured by the polity score, which consists of an evaluation of the competitiveness and openness of elections, the nature of political participation in general, and the extent of checks on executive authority. A high positive score corresponds to strong democratic institutions; negative scores indicate more autocratic systems. Trade openness is measured by the inverted Hiscox Kastner score, which gauges the degree to which a country deviates from an optimal level of imports from a hypothetical protection-free environment. Higher scores indicate greater openness. GDP = gross domestic product.) ///	
		source(Ansell (2010).) ///
		chapter(11) figure(3)

exit
