/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	import data
	use "${data}/Education Commission 2016 sources of education funding", clear
	
***	fix labels
	replace category=subinstr(category,"-"," ",.)
	lab var category "Income group"

***	calculate percentages
	ds category, not
	local datavars `r(varlist)'
	egen total=rowtotal(`datavars')
	
	foreach var of local datavars {
		replace `var'=(`var'/total)*100
		}
	drop total
	
***	rename variables
	rename (Domesticpublicspending Households Internationalfinance) ///
			(domestic household international)
		
***	archive data
	wdrarchive
	
/*******************************************************************************
GRAPH
*******************************************************************************/


	
***	graph
graph bar domestic household international, ///
	over(category, /// 
		relabel(1 `""Low" "income""' ///
				2 `""Lower middle" "income""' ///
				3 `""Upper middle" "income""' ///
		)) ///
		stack ///
	legend(region(c(none))  symx(3) symy(3) ///
		label(1 "Domestic" "public") ///
		label(2 "Households") ///
		label(3 "International" "finance") ///
		order(3 2 1) ///
		c(1) pos(3) ///
		) ///
	graphregion(c(white) lw(thick) lc(white)) ///
		bar(3, color("${wdrscheme5}") fi(100)) ///
		bar(2, color("${wdrscheme4}") fi(100)) ///
		bar(1, color("${wdrscheme1}") fi(100)) ///
	ytitle("Percent") ///
	ylabel(0(20)100, notick angle(h) glc(gs2) glp(shortdash) glw(thin)) ///
	yscale(noline) ///
	ysize(3) xsize(4.25) ///
	scale(1.2)
	
/*******************************************************************************
EXPORT
*******************************************************************************/
	
	wdrexport , ///
		title(Most funding for education comes from domestic sources, but international finance is important for low-income countries) ///
		subtitle(Estimated sources of education spending, by income group (2015)) ///
		source(Education Commission (2016).) ///
		chapter(11) figure(4)

exit
