/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	import data
	use "${data}/Montez Hummer and Hayward 2012 mortality rates", clear
	
***	archive data
	wdrarchive

***	save
	tempfile working
	save `working', replace
	
/*******************************************************************************
GRAPH
*******************************************************************************/

local pattern1 solid
local pattern0 shortdash

levelsof group, local(groups)
local i=0
foreach group of local groups {
	local ++i
	local pattern =mod(`i',2)
	local color	=ceil(`i'/2)
	use `working', clear
	qui keep if group=="`group'"
	local scat `scat' (scatter mortality  yearsed if group=="`group'", sort c(l) lp(`pattern`pattern'') lc("${wdrscheme`color'}") m(none))
	local leglab `leglab' label(`i' "`group'")
	}

use `working', clear

twoway `scat', ///
	legend(`leglab' colfirst region(c(none)) c(1) symx(4) symy(4) pos(3)) ///
	ylabel(-.8(.4)1.2, nogrid angle(horizontal)) ///
	graphregion(c(white)lc(white)lw(thick)) ///
	ytitle("Odds of death") xtitle("Years of education") ///
	xsize(4.5) ysize(2.5) scale(1.3)

/*******************************************************************************
EXPORT
*******************************************************************************/
	
	wdrexport , ///
		title(Mortality rates are lower for adults with more education) ///
		subtitle(Relative odds (log-odds coefficient) of death for groups with different years of education, by age, gender, and race) ///
		source(WDR 2018 team, using data from Montez, Hummer, and Hayward (2012).) ///
		note(Groups exclude Hispanic population.) ///
		chapter(1) figure(2)

exit

