/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

*** import data 
	use "${data}/World Values Survey 2015 democracy and education", clear

***	archive data
	wdrarchive
	
***	generate sort variable	
	sort category tertiary
	gen sort=_n+3*category
	
*** reshape
	rename (primary tertiary) support=
	reshape long support, i(country category) j(attainment) str
	format support %3.0fc
	
/*******************************************************************************
GRAPH
*******************************************************************************/

***	set locals for graphing
	levelsof category, local(categories)
	sum sort 
	local maxrank =`r(max)'
	local leftmargin 3
	tokenize `c(alpha)'
	
***	set labels and titles for y axis
	local ylbl 0(20)100, notick grid glp(shortdash) glw(thin) glc(gs8) angle(h)
	local ytit "Percent"
			
***	commands for connecting lines
	levelsof sort, local(sorts)
		foreach sort of local sorts {
		local clines `clines' (scatter support sort if sort ==`sort' , m(none) c(l) lw(thin) lc(gs2) )
			}

***	set titles
	local xadjust 1
	local y 110
	sum sort if category==1
	local x=`r(min)'-`xadjust'
	local addedtext text(`y' `x' "{bf:a. Low- and middle-income countries}", placement(e) color(black) size(medium))
	sum sort if category==2
	local x=`r(min)'-`xadjust'
	local addedtext `addedtext' text(`y' `x' "{bf:b. High-income countries}", placement(e) color(black) size(medium))
		
***	set markerlabels
	sum sort
	local x=`r(max)'
	local xcoord=`x'+1
	sum support if sort==`x' & attainment=="tertiary"
	local y=`r(mean)'
	local markerlabels text(`y' `xcoord' "People with" "tertiary education", placement(e) just(left) color("$wdrscheme4"))
	sum support if sort==`x' & attainment=="primary"
	local y=`r(mean)'
	local markerlabels `markerlabels' text(`y' `xcoord' "People with" "primary education", placement(e) just(left) color("$wdrscheme2"))
	
***	graph

	twoway ///
		`clines' ///
		(scatter support sort if attainment=="tertiary" , m(o) mc("$wdrscheme4") ) ///
		(scatter support sort if attainment=="primary"  , m(o) mc("$wdrscheme2") ) ///
			, ///
		graphregion(c(white)lc(white)lw(thick)margin(r+29 t+5)) ///
		legend(off) ///
		ylabel(`ylbl') ///
		ytitle(`ytit') ///
		`addedtext' ///
		`markerlabels' ///
		yscale(range(0 100) noline) ///
		xlabel(none) xscale( noline) ///
		xtitle(" ") ///
		xsize(6.5) ysize(3) ///
		scale(1.2) ////
		name(democracy, replace)

/*******************************************************************************
EXPORT
*******************************************************************************/

wdrexport , ///
	title(People with higher education hold stronger beliefs about the importance of democracy) ///
	subtitle(Percentage of population that believes it is absolutely important to live in a democracy, by country and level of education) ///
	source(WDR 2018 team, using data from World Values Survey (World Values Survey Association 2015).) ///
	chapter(1) figure(3)

exit
