
/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	import data
	use "${data}/Kaffenberger and Pritchett 2017 varied learning", clear
		
*** archive data
	preserve
	keep country levstr literacy
	local lbl : var lab levstr
	local lbl =subinstr("`lbl'", " (string)","",.)
	lab var levstr "`lbl'"
	rename levstr level
	order country level, first
	wdrarchive
	restore

***	save temp
	tempfile working
	save `working'

/*******************************************************************************
GRAPH
*******************************************************************************/

local pattern1 solid
local pattern0 shortdash

levelsof country, local(countries)
local i=0
foreach country of local countries {
	local ++i
	local pattern =mod(`i',2)
	local color	=ceil(`i'/2)
	use `working', clear
	qui keep if country=="`country'"
	local scat `scat' (scatter literacy level if country=="`country'", sort c(l) lp(`pattern`pattern'') lc("${wdrscheme`color'}") m(none))
	local leglab `leglab' label(`i' "`country'")
	}

	local ycoord -22
	local addsize medsmall
	local addedtext 			text(`ycoord' 1 "No formal" "education"			, placement(s) size(`addsize') )
	local addedtext `addedtext' text(`ycoord' 2 "Some" "primary"					, placement(s) size(`addsize'))
	local addedtext `addedtext' text(`ycoord' 3 "Completed" "primary"				, placement(s) size(`addsize'))
	local addedtext `addedtext' text(`ycoord' 4 "Some" "secondary"				, placement(s) size(`addsize'))
	local addedtext `addedtext' text(`ycoord' 5 "Completed" "secondary"			, placement(s) size(`addsize'))
	local addedtext `addedtext' text(`ycoord' 6 "Some or" "completed" "tertiary"	, placement(s) size(`addsize'))
	
	
	
use `working', clear
twoway `scat', ///
	legend(`leglab' colfirst region(c(none)) c(1) symx(4) symy(4) pos(3)) ///
	ylabel(0(25)100, nogrid angle(horizontal)) ///
	xlabels(, tick nolabels) ///
	`addedtext' ///
	xscale(noline) ///
	yscale(noline) ///
	plotregion(margin(r+5 l+5 b+5)) ///
	graphregion(c(white)lc(white)lw(thick)) ///
	ytitle("Percent literate") ///
	xtitle("Highest level of educational attainment", margin(t+13)) ///
	xsize(5) ysize(2.5) scale(1.3)

/*******************************************************************************
EXPORT
*******************************************************************************/

wdrexport , ///
	title(Learning varies widely across countries; in 6 of the 10 countries assessed only half or less of primary completers can read) /// 
	subtitle(Literacy rates at successive education levels, selected countries) ///
	source(Kaffenberger and Pritchett 2017.) ///
	note(Literacy is defined as the being able to read a three-sentence passage either fluently without help or well but with a little help.) ///
	chapter(1) figure(4) 
	
exit
