/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	import data
	use "${data}/Hanushek and Woessmann 2010 simulated growth change", clear
	
***	trim data
	keep country *gdp
	
***	archive data
	wdrarchive

/*******************************************************************************
GRAPH
*******************************************************************************/

***	graph
	graph bar s3_gdp s2_gdp,   ///
		over(country, label(angle(45)) sort(s2_gdp) des) ///
		bar(1 , color("$wdrscheme6")) ///
		bar(2 , color("$wdrscheme2")) ///
		name(`type', replace) ///
		xsize(6.5) ysize(3) ///
		ylabel(, angle(h) glc(gs2) glp(shortdash) glw(thin)) ///
		graphregion(c(white)lc(white)lw(thick)) ///
		legend( ///	
			region(c(none)) c(1) symx(3) symy(3) ///
			label(1 "Bring all test-takers to a minimum of 400 points on PISA") ///
			label(2 "Bring each country average to the Finnish average of 546 points on PISA") ///
			) ///
		ytitle("Percent of current GDP") 
			
/*******************************************************************************
EXPORT
*******************************************************************************/

wdrexport , ///
	title(Increasing learning would yield major economic benefits) ///
	subtitle(Simulated additional GDP between 2015 and 2090 attributable to increased learning (relative to current GDP), by scenario in selected countries) ///
	source(OECD 2010.) ///
	note(PISA = Programme for International Student Assessment.) ///
	chapter(1) figure(6)
	
exit

