/*******************************************************************************
World Development Report 2018: Education
Written by: Bradley Larson (BLarson@worldbank.org)
Primary and secondary enrollments have shot up in developing countries
line chart using Lee and Lee, 1825-2010
*******************************************************************************/

***	WDR settings
	include wdrsettings 
	
/*******************************************************************************
PREP DATA
*******************************************************************************/
	
***	load and trim data
	use "${data}\Lee and Lee 2016 learning stock collapsed", clear
	decode category, gen(catstring)
	drop if category==9	
	keep if gender==3
	drop gender region l?
	sum year
	local minyr `r(min)'
	local maxyr	`r(max)'
	tempfile areacollapse
	save `areacollapse'

***	renumber the categories, since we are not including North America (category 5)
	use `areacollapse', clear
	keep category
	duplicates drop
	decode category, gen(cat)
	sort category
	gen graph_cat =_n
	levelsof graph_cat, local(cats)
	foreach cat of local cats {
		local lbl `lbl' `cat' "`=cat[`cat']'"
		}
	noi di `"`lbl'"'
	label define graph_cat `lbl'
	label val graph_cat graph_cat
	merge 1:m category using `areacollapse', nogen
	save `areacollapse', replace

***	archive
	foreach var in pri sec {
	preserve
	lab var pri "Primary enrollment"
	lab var sec "Secondary enrollment"
	keep catstring year `var' 
	rename catstring category
	order category, first
	sort category year
	wdrarchive
	restore
	}
	
/*******************************************************************************
GRAPH
*******************************************************************************/

***	set colors
	local m1  $wdrscheme1
	local m2  $wdrscheme2
	local m3  $wdrscheme3
	local m4  $wdrscheme4
	local m5  $wdrscheme5
	local m6  $wdrscheme6
	local m7  $wdrscheme8

***	set labels
	local pri_lbl "a. Primary school"
	local sec_lbl "b. Secondary school"
	local x_ttl_sec  "Year"
	local x_ttl_pri   "Year"
	local ytit_sec	"Net enrollment rate"
	
***	establish graphing commands
	levelsof graph_cat, local(categories)
	local interestvars pri sec
	
		foreach var of local interestvars {
		foreach category of local categories {
			local lbl : label graph_cat `category'
			local `var'_scat ``var'_scat' (scatter `var' year if graph_cat==`category', m(none) c(l) lc("`m`category''") lp(solid) lw(thick) sort)
			local `var'_lg ``var'_lg' (scatter `var' year if graph_cat==0, m(none) c(l) lc("`m`category''") lp(solid) lw(medium) sort)
			local `var'_labl ``var'_labl'  label(`category' `lbl')
			}
			}
		
***	graph
	foreach var of local interestvars  {
		local ttl : var label `var'
		twoway ``var'_scat' , ///
		ytitle("`ytit_`var''") ///
		title("{bf:``var'_lbl'}", size(medium) color(black) bexpand just(left)  ) ///
		ytitle(, size(medium) m(l-2) ) ylabels(, nogrid angle(horizontal)) ///
		ylabel(0(20)100, angle(horizontal) nogrid labs(medlarge)) ///
		xlabel(1825(25)2000, labs(medium)) ///
		xtitle("`x_ttl_`var''", size(medium) margin(t+1)) /// 
		xscale(r(1825 2000)) /// 		yscale(alt) /// 		
		legend(``var'_labl' region(c(none)m(l-3)) colfirst holes(4) symy(3) symx(3.5) pos(6)  col(2) size(small) keygap(*.75)) ///
		graphregion(c(white)lc(white)lw(thick) m(l-2 b-3)) ///
		fxsize(140) ///
		name(scat_`var', replace)
		}

*** combine graphs
	grc1leg scat_pri scat_sec  , c(2) graphregion(c(white)lc(white)lw(thick)margin(t-1 r-1 l-1 b-4)) imargin(0 0 0 0) name(enrollment, replace) iscale(.75)
	graph display enrollment, ysize(3.5) xsize(6.5) scale(1.15)

/*******************************************************************************
EXPORT
*******************************************************************************/

wdrexport , ///
	title(School enrollments have shot up in developing countries) ///
	subtitle(Net enrollment rates, by country group (1820-2010)) ///
	source(WDR 2018 team, using data from Lee and Lee (2016).) ///
	chapter(2) figure(1) 

exit
