/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
Figure 2.6 multiple exclusions
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREP DATA
*******************************************************************************/

***	load data
	use "${data}/DHS 2012 multiple exclusions", clear
	tempfile build
	save `build'

***	archive
	preserve
	decode group, gen(grp)
	drop group
	rename grp group
	order country group, first
	sort country group grade
	wdrarchive
	restore
	
/*******************************************************************************
GRAPH
*******************************************************************************/

***	define levels of variables
	levelsof country, local(countries)
	levelsof group, local(groups)
	
***	set labels
	local Pakistan_ytit "Percentage"
	local Pakistan_tit "Pakistan"
	local Mali_tit "Mali"
	local Peru_tit "Peru"
	local Indonesia_tit "Indonesia"
	
*** set graphing codes
	foreach country of local countries {
		use `build', clear
		qui keep if country=="`country'"
		foreach group of local groups {
			local scat`country' `scat`country'' (scatter pct grade if country=="`country'" & group==`group', c(l) m(none) lw(medthick) lc("${wdrscheme`group'}"))
			}
			}

***	graph
	foreach country of local countries {
		use `build', clear
		twoway `scat`country'', ///
			ylabels(0(20)100,angle(h) nogrid) ///
			ytitle("``country'_ytit'") ///
			xtitle("Grade") ///
			title("``country'_tit'", bexpand just(left) color(black) size(medium)) ///
			xlabels(1(1)9) ///
			graphregion(c(white)lc(white)lw(thick)) ///
			legend(off) ///
			aspectratio(1) ///
			name(s`country', replace) 
		}

*** graph legend
	foreach group of local groups {
		local scatlegend `scatlegend' (scatter pct grade if country=="" & group==`group', c(l) m(none) lw(medium) lc("${wdrscheme`group'}"))
		}
	twoway `scatlegend', ///
		yscale(noline) ///
		xscale(noline) ///
		graphregion(c(white)lc(white)lw(thick)) ///
		ytitle("") xtitle("") ///
		legend( ///
				label(1 "Poorest quintile") ///
				label(2 "Girls in the poorest quintile") ///
				label(3 "Middle quintile") ///
				label(4 "Richest quintile") ///
				region(c(none)) ///
				symx(3) symy(3) ///
				r(1) ///
				order(4 3 1 2) ///
				size(vsmall) ///
			) ///
			fxsize(0) ///
			name(leg)

***	combine panels
	grc1leg leg sPakistan sMali sPeru sIndonesia, r(1) graphregion(c(white)lc(white)lw(thick)) imargin(0 0 0 0) name(multiple_exclusions, replace)
	graph display multiple_exclusions, ysize(2.25) xsize(6.5) scale(2) 
	graph drop leg s*
	
/*******************************************************************************
EXPORT
*******************************************************************************/

	wdrexport , ///
		title(Multiple exclusions: Girls from poor households often have the lowest rates of education attainment) ///
		subtitle(Percentage of youth (ages 15-19) who have completed each grade, by wealth quintile and gender, selected countries (2012)) ///
		source(WDR 2018 team, using data from U.S. Agency for International Development’s Demographic and Health Surveys for 2012 (www.dhsprogram.com).) ///
		chapter(2) figure(6)
