/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	import and clean data
	use "${data}/Various sources 2002-2013 teaching time", clear
	
***	time teaching is greater than time present in some instances; for now, make them equal
	replace inclass=ontask if ontask>inclass 
	
***	graph the denominator
	gen scheduled=100

***	label variables
	lab var country "Country"
	lab var inclass "Percentage of scheduled time teacher is present in classroom"
	lab var ontask "Percentage of scheduled time teacher is teaching"
	lab var scheduled "Percentage of scheduled time teacher is scheduled"

***	archive
	wdrarchive
	
/*******************************************************************************
GRAPH
*******************************************************************************/

***	graph
	graph bar scheduled inclass ontask, ///
		over(country, ///
				sort(ontask) descending ///
				label(angle(45)) ///
				  ///
				) ///
		bar(1, color("${wdrscheme1}") fi(100) lw(none)) ///
		bar(2, color("${wdrscheme3}") fi(100) lw(none)) ///
		bar(3, color("${wdrscheme4}") fi(100) lw(none)) ///
			xsize(6.5) ysize(2.75) ///
				legend(region(c(none) margin(l-4)) ///
			label(1 "Scheduled" "to teach") ///
			label(2 "Present in" "the classroom") ///
			label(3 "Teaching") ///
			symx(4) symy(2.8) ///
			pos(3) c(1) ///
			size(medsmall) ///
			title("Percentage of time" "teacher is:", size(medsmall) color(black) margin(l+3) just(left)) ///
			) ///
		plotregion(margin(l-2 r-2)) ///
		yscale(noline) ///
		ylabels(,angle(horizontal) notick glc(gs2) glw(vthin) labsize(medsmall) glp(shortdash)) ///
		graphregion(c(white)lc(white)lw(thick)margin(l-3 r-9 b-5 t-5)) ///
		ytitle("Percent", margin(r-2) size(medsmall)) ///
		scale(1.3)
			
/*******************************************************************************
EXPORT
*******************************************************************************/
				
wdrexport , ///
	title(A lot of official teaching time is lost) ///
	subtitle(Percentage of time officially allocated to schooling, when a teacher is present at school, and actually spent on teaching and learning) ///
	source(WDR 2018 team, using data from Millot and Lane (2002): Arab Republic of Egypt, Lebanon, and Republic of Yemen; Abadzi (2009): Ghana, Brazil (Pernambuco state), Morocco, and Tunisia; Benveniste, Marshall, and Santibañez (2007): Lao People’s Democratic Republic; Benveniste, Marshall, and Araujo (2008): Cambodia; World Bank’s Service Delivery Indicators, 2012–13 (www.worldbank.org/sdi): Kenya, Mozambique, Nigeria, Senegal, Togo, Tanzania, and Uganda; World Bank (2016a): Madagascar; World Bank (2016b): Zambia.)  ///
	note(For Brazil, Cambodia, Ghana, Lao PDR, Senegal, Tanzania, and Tunisia, data include public schools. For all other countries, data include both public and private schools.) ///
	chapter(3) figure(10)

