/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings

/*******************************************************************************
prep data
*******************************************************************************/

***	import data
	use "${data}/Sandefur 2017", clear
	drop pop
	
***	archive
	***	preserve
		preserve	
	***	reshape and rename	
		forvalues x=1/3 {
			rename pop_g`x'_* *`x'
			}
		reshape long t1 t2 t3 t4, i(income) j(grade) str
		rename income category
	***	label variables
		lab var t1 "International: PIRLS, PISA, TIMSS"
		lab var t2 "Standardized regional: LLECE, PASEC, SACMEQ"
		lab var t3 "Non-standardized regional: ASER, EGRA"
		lab var t4 "None"
		lab var category "Country category"
		lab var grade "Grade level"
		tokenize `""Grades 2-3" "Grades 4-6" "Grades 8-10""'
		forvalues x=1/3 {
			replace grade ="``x''" if grade=="`x'"
			}
	***	order, sort, trim, and export
		order grade, first
		sort grade incgroup
		drop incgroup
		wdrarchive
	***	restore
		restore
	
/*******************************************************************************
graph
*******************************************************************************/

***	set options
	local lgnd ///
		label(1 "International" "PIRLS, PISA, TIMSS") ///
		label(2 "Standardized regional" "LLECE, PASEC, SACMEQ") ///
		label(3 "Non-standardized regional" "ASER, EGRA") ///
		label(4 "None") 
	tokenize `""a. Grades 2–3" "b. Grades 4–6" "c. Grades 8–10""'
	sort incgroup
	
forval n = 1/3 {
			graph bar pop_g`n'_t3 pop_g`n'_t2 pop_g`n'_t1 pop_g`n'_t4, stack nofill ///
			over(incgroup, relabel(1 `""High-" "income""' 2 `""Middle-" "income""' 3 `""Low-" "income""' 4 "World"))  ///
			title({bf:``n''}, bexpand just(left) size(medsmall) color(black)) ///
			legend(title("Type of exam:", size(medsmall) margin(r+2) color(black) just(right) pos(9)) `lgnd' r(1) region(c(none)m(t-2)) order(2 3 1 4) symx(3) symy(3) size(medsmall)) ///
			graphregion(c(white)lw(thick)lc(none)margin(l-3 r-4)) ///
			bar(1, col(${wdrscheme1})) ///
			bar(2, col(${wdrscheme2})) ///
			bar(3, col(${wdrscheme3})) ///
			bar(4, col(${wdrscheme5})) ///
			yscale(noline) ///
			ylabels(, angle(h) grid glc(gs4) glp(shortdash) glw(thin) notick labsize(medsmall)) ///
			name(g`n', replace)
			}

***	combine
	grc1leg g1 g2 g3, graphregion(c(white)lw(thick)lc(none)margin(t-5 l-3)) r(1) name(combo) iscale(1.05)  // 
	graph draw combo, xsize(6.5) ysize(2) scale(1.6)
	
/*******************************************************************************
export
*******************************************************************************/
	
	wdrexport , ///
		title(No internationally comparable data on learning are available for most children outside of high-income countries) ///
		subtitle(Percentage of children in countries that have reported mathematics and reading scores since 2000 for ASER, EGRA, LLECE, PASEC, PIRLS, PISA, SACMEQ, and TIMSS) ///
		source(WDR 2018 team, using data from Sandefur (2017).) ///
		note(ASER = Annual Status of Education Report; EGRA = Early Grade Reading Assessment; LLECE = Latin American Laboratory for Assessment of the Quality of Education; PASEC = Programme d’Analyse des Systèmes Educatifs de la Confemen; PIRLS = Progress in International Reading Literacy Study; PISA = Programme for International Student Assessment; SACMEQ =  Southern and Eastern Africa Consortium for Monitoring Educational Quality; TIMSS = Trends in International Mathematics and Science Study.) ///
		chapter(4) figure(1)

