/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	load data
	use "${data}/Kattan 2006 and WDI 2017 school fees", clear

***	archive data
	sort country year
	wdrarchive
	
***	generate marker label
	sum before_after
	gen mlabel=country if before_after==`r(max)'
	gen 	mlabpos=3
	replace mlabpos=4 if country=="Uganda" | country=="Cameroon" | country=="Zambia" 
	
/*******************************************************************************
GRAPH
*******************************************************************************/

***	set locals
	levelsof country, local(countries)
	ds i_*
	local interpolatedvars `r(varlist)'
	local lp1 solid
	local lp0 shortdash		
	
***	loop for graphing commands
	local counter=0
	foreach var of local interpolatedvars {
		foreach country of local countries {
			local ++counter
			local color=ceil(`counter'/2)
			local pattern=mod(`counter',2)
			noi di "`country' `lp`pattern''"
			local `var'scats ``var'scats' (scatter `var' before_after if country=="`country'" & , c(l) lc("${wdrscheme`color'}") lw(thick) lp(`lp`pattern'') m(none) mlabvpos(mlabpos) mlabsize(small) mlabel(mlabel) mlabc("${wdrscheme`color'}"))
			}
			}
		
	foreach var of local interpolatedvars {
		twoway ``var'scats',  ///
			legend(off) ///
			graphregion(c(white)lc(white)lw(thick)margin(r+15)) ///
			ylabel(60(20)160, angle(h) glc(gs2) glp(shortdash) glw(thin)) ///
			xline(0, lc(gs0) lp(solid) lw(thin)) ///
			ytitle("Gross enrollment (%)") ///
			xtitle("Years before and after elimination of school fees") ///
			xsize(5) ysize(5) ///
		name(g`var', replace)
		}
		
/*******************************************************************************
EXPORT
*******************************************************************************/
	
	wdrexport , ///
		title(What happens when school fees are eliminated? Evidence from eight countries) ///
		subtitle(Gross enrollment in years before and after elimination of school fees, selected countries) ///
		source(WDR 2018 team, using data from World Development Indicators 2017 (data.worldbank.org/products/wdi); year of policy change from Bentaouet Kattan (2006).) ///
		note(Vertical line indicates last year with fees.) ///
		chapter(5) figure(4)

	exit
