/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/
	
***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	import data
	use "${data}/Oye Sandefur and Pritchett 2016 literacy and schooling", clear

***	archive
	forvalues x=0/6 {
		lab var grade`x' "Women's literacy (percent) if Grade `x' is highest completed"
		}
	lab var country "Country"
	wdrarchive
	
***	reshape
	rename grade* literacy*
	reshape long literacy, i(country) j(grade)
	
***	fix values/gen vars
	replace country="Average" if country=="Average 52 countries"
	sum grade
	gen mlabel=country if grade==`r(max)'
	gen mlabvpos=3
	replace mlabvpos=2 if country=="Peru"
	
/*******************************************************************************
GRAPH
*******************************************************************************/
	
***	set locals
	levelsof country, local(countries)
	local counter=0
	
***	set commands	
	foreach country of local countries {
		local ++counter
		noi di "`country' `lp`pattern''"
		local scats `scats' (scatter literacy grade if country=="`country'" & , c(l) lc("${wdrscheme`counter'}") lw(thick) lp(solid) m(none) mlabvpos(mlabvpos) mlabsize(small) mlabel(mlabel) mlabc("${wdrscheme`counter'}"))
		}
			
***	graph	
	twoway `scats',  ///
		legend(off) ///
		graphregion(c(white)lc(white)lw(thick)margin(r+15)) ///
		ylabel(0(20)100, angle(h) glc(gs2) glp(shortdash) glw(thin)) ///
		ytitle("Literacy (%)") ///
		xtitle("Highest grade completed") ///
		xsize(3) ysize(2.5) ///
		scale(1.3) ///
	name(female_lit_grades, replace)
		
/*******************************************************************************
EXPORT
*******************************************************************************/

	wdrexport , ///
		title(Not all education systems are equally productive, but even the least productive deliver some learning to some learners) ///
		subtitle(Percentage of women ages 25-34, by highest grade completed, who can read all of a single sentence in their chosen language, selected countries) ///
		source(Oye, Pritchett, and Sandefur (2016).) ///
		note(The average is calculated across 52 countries.) ///
		chapter(5) figure(5)

exit
