/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

*** WDR settings
	include wdrsettings

/*******************************************************************************
PREPARE DATA
*******************************************************************************/

*** load data
	use "${data}/Muralidharan and Zieleniak 2013", clear

***	reshape
	rename grade* pctcorrect*
	reshape long pctcorrect, i(category) j(grade)
	
***	trim and encode
	replace category=trim(category)
	encode category, gen(cat)
	
***	define line types
	gen 	linetype=2
	replace linetype=1 if category=="1st Grade Standard"
	replace linetype=1 if category=="5th Grade Standard"
		
***	generate mlabels
	sum 	grade
	gen 	mlabel=category if grade==`r(max)' & linetype==2
	replace mlabel=category if grade==`r(max)' & linetype==1
	
***	rescale
	replace pctcorrect=100*pctcorrect
	format  pctcorrect %3.0fc
	
***	save temp
	tempfile working
	save `working', replace

***	archive data
	preserve
	keep category grade pctcorrect
	rename category stat
	lab var stat "Percentile or standard"
	lab var grade "Grade"
	lab var pctcorrect "Correct answers (%)"
	wdrarchive
	restore

/*******************************************************************************
GRAPH
*******************************************************************************/

***	set graph options
	local mlabpos11 7
	local mlabpos12 11
	local mlabpos21 3
	local mlabpos22 5
	local mlabpos23 3
	local color1 "${wdrscheme1}"
	local color2 "${wdrscheme5}"
	
	
***	set labels and lines for standards
	sum pctcorrect if category=="5th Grade Standard"
	local 5th_ycoord `r(mean)'
	sum pctcorrect if category=="1st Grade Standard"
	local 1st_ycoord `r(mean)'
	sum grade
	local xcoord=`r(max)'+.5
	
	local standard_5 yline(`5th_ycoord', lc(`color1') lw(thick)) text(`5th_ycoord' `xcoord' "Grade 5 standard   ", placement(e) just(left) color(`color1') )
	local standard_1 yline(`1st_ycoord', lc(`color1') lw(thick)) text(`1st_ycoord' `xcoord' "Grade 1 standard   ", placement(e) just(left) color(`color1') )


***	loop for graph commands
	drop if linetype==1
	levelsof linetype, local(types)
	foreach type of local types {
		use `working', clear
		keep if linetype==`type'
		levelsof category, local(categories)
		local categorycounter 0
		foreach category of local categories {
			local ++categorycounter
			local scat `scat' (scatter pctcorrect grade if category=="`category'", c(l) m(none) lw(thick) lc("`color`type''") mlabel(mlabel) mlabsize(medsmall) mlabc("`color`type''") mlabpos(`mlabpos`type'`categorycounter'') )
			}
			}
		
		use `working', clear
		
	twoway `scat', ///
		graphregion(c(white)lc(white)lw(thick)margin(r+35)) ///
		legend(off) ///
		ylabel(0(20)100, labgap(2) angle(h) glc(gs2) glw(thin) glp(shortdash) notick) ///
		xscale(noline) yscale(noline) ///
		xtitle("Grade") ytitle("% correct") ///
		`standard_5' ///
		`standard_1' ///
		plotregion(margin(r+4 l+4)) ///
		xsize(4) ysize(2.75) ///
		scale(1.2)
		
	
/*******************************************************************************
EXPORT
*******************************************************************************/
	
	wdrexport , ///
		title(Only a small fraction of learners keep up with the curriculum) ///
		subtitle(Percentage of correct answers on a math test in India relative to curriculum standards, by grade) ///
		source(WDR 2018 team, using data from Muralidharan and Zieleniak (2013).) ///
		chapter(6) figure(1)

exit
