/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

*** WDR settings
	include wdrsettings

/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	import
	use "${data}/OECD 2016 teachers and engineers", clear
	drop if subject=="Science"
	drop average

***	archive
	wdrarchive

***	create ranking variables 
	foreach var in teachers engineers {
		bysort subject (`var'): gen `var'_rank=_n
		}
		

***	pull labels
	
	foreach var in engineers teachers  {
		lab var `var' "Prospective `var'"
		local `var'lbl : var label `var'
		}
	
***	reshape again to get career goal in long
	rename (teachers engineers) score=
	reshape long score  , i(country code subject) j(prospective) str
	


***	replace varname strings with label strings
	levelsof prospective, local(prospects)
	foreach prospect of local prospects {
		replace prospective="``prospect'lbl'" if prospective=="`prospect'"
		}
	encode prospective, gen(prospect)
	order prospect, before(prospective)
	rename prospective prospect_lbl
	
***	save temp
	tempfile working
	save `working'


/*******************************************************************************
GRAPH
*******************************************************************************/

***	set locals for graphing
	local rankby engineers
	local subjects Mathematics Reading
	levelsof `rankby'_rank, local(ranks)
	local numranks : word count `ranks'
	local maxrank : word `numranks' of `ranks'
	local legend1=`maxrank'+1
	local legend2=`maxrank'+2
	local leftmargin 3
	tokenize `c(alpha)'
	
***	set colors
	local color2 "$wdrscheme3"
	local color1 "$wdrscheme1"
	
	/*
***	set marker labels
	preserve
	keep if subject=="Reading" & `rankby'_rank==`maxrank' 
	splitstring prospect_lbl
	count
	sort prospect_lbl
	local markerx = `maxrank'+1
	forvalues r=1/`r(N)' {
		local Readingmarkerlabels `Readingmarkerlabels' text(`=score[`r']' `markerx' "`=prospect_lbl_line1[`r']'" "`=prospect_lbl_line2[`r']'", color("`color`r''") size(small) placement(e) just(left))
		}
	restore
*/

***	set labels and titles for y axis
	foreach subject of local subjects {
		local `subject'_ylbl #5, nolabel notick grid glp(shortdash) glw(thin) glc(gs8)
		local `subject'_ytit """"
		}

***	text for ylabels
	forvalues y=300(100)600 {
		local Mathematics_txt `Mathematics_txt' text(`y' -2 "`y'", placement(w) color(black) size(small)) 
		}
	local Mathematics_txt `Mathematics_txt' text(450 -8 "Score", placement(w) color(black) size(medsmall) orientation(vertical) ) 
	
***	commands for connecting lines
	local legendcount=0
	
	foreach rank of local ranks {
	local ++legendcount
	foreach subject of local subjects {
		local `subject'ranklines ``subject'ranklines' (scatter score `rankby'_rank if `rankby'_rank ==`rank' & subject=="`subject'", m(none) c(l) lw(thin) lc(gs2) sort)
		}
		}
	local legendcount1=`legendcount'+1
	local legendcount2=`legendcount'+2
	
***	graph
local panelcount 0
sum prospect
local maxprospect `r(max)'
local minprospect `r(min)'
foreach subject of local subjects {
	local ++panelcount
	twoway ///
		 ``subject'ranklines' ///
		(scatter score `rankby'_rank if prospect==`minprospect' & subject=="`subject'", m(o) mc("`color1'") ) ///
		(scatter score `rankby'_rank if prospect==`maxprospect' & subject=="`subject'", m(o) mc("`color2'") ) ///
			, ///
		graphregion(c(white)lc(white)lw(thick)margin(l-`leftmargin')) ///
		plotregion(margin(l-1 r-1)) ///
		legend(r(1) order(`legendcount1' `legendcount2' ) ///
			label(`legendcount1' "Prospective engineers") ///
			label(`legendcount2' "Prospective teachers") ///
			region(c(none))) ///
		ylabel(``subject'_ylbl') ///
		ytitle(``subject'_ytit') ///
		``subject'_txt' ///
		``subject'markerlabels' ///
		yscale(noline) ///
		title("{bf:``panelcount''. `subject'}", bexpand just(left) color(black) size(medsmall)) ///
		xlabel(none) xscale(range(0 `maxrank') noline) ///
		xtitle(" ") ///
		name(g`subject', replace)
		local spreadmerge `spreadmerge' g`subject'
	}
	
	grc1leg gMathematics gReading , r(1) imargin(2 2 0 0) ycommon name(spread, replace) iscale(.95) graphregion(c(white)lc(white)lw(thick)margin(l+10 r+19)) xsize(6.5) ysize(3)
	graph draw spread, scale(1.2)  xsize(6.5) ysize(3) 

/*******************************************************************************
EXPORT
*******************************************************************************/
	wdrexport , ///
		title(Prospective engineers typically score higher than prospective teachers on PISA tests) ///
		subtitle(PISA 2015 scores for participating countries, by subject and prospective occupation) ///
		source(WDR 2018 team, using data from OECD (2016b).) ///
		note(PISA = Programme for International Student Assessment) ///
		chapter(6) figure(2) 
	

exit 
