/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

*** WDR settings
	include wdrsettings

/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	import data
	use "${data}/Muralidharan and others 2017 ICT interventions", clear

***	replace counts with percentages
	local impacts negative none positive
	egen interventions_count=rowtotal(`impacts')
	foreach var of local impacts {
		replace `var'=(`var'/interventions_count)*100
		local lbl : var label `var'
		lab var `var' "`lbl' (percent)"
		}
	drop interventions

***	archive data
	wdrarchive

/*******************************************************************************
GRAPH
*******************************************************************************/

***	do calculations for text labels
	foreach var of local impacts {
		sum `var' if type=="Hardware"
		local `var'value=`r(mean)'
		}
	local negative_ycoord = `negativevalue'/2
	local none_ycoord = (`nonevalue'/2) +`negativevalue'
	local positive_ycoord =(`positivevalue'/2) + `negativevalue' +`nonevalue'
	local xcoord 102
	local topts placement(e)
	
***	graph
	graph bar (asis) negative none positive, ///
		over(type, des gap(*.5)) stack ///
		text(`negative_ycoord' 	`xcoord' "Negative effect"	, `topts' color($wdrscheme7)) ///
		text(`none_ycoord' 		`xcoord' "No effect"		, `topts' color($wdrscheme1)) ///
		text(`positive_ycoord' 	`xcoord' "Positive effect"	, `topts' color($wdrscheme5)) ///
		bar(1, fi(100) color($wdrscheme7) ) ///
		bar(2, fi(100) color($wdrscheme1) ) ///
		bar(3, fi(100) color($wdrscheme5) ) ///
		graphregion(c(white)lc(white)lw(thick)margin(r+30)) ///
		plotregion(margin(r-3 l-3)) ///
		ylabel(0(20)100, glc(gs2) glw(thin) glp(shortdash) notick angle(h)) ///
		ytitle("Percent") ///
		legend(off) ///
		xsize(3) ysize(3) ///
		yscale(noline) ///
		scale(1.3) ///
		name(impact_bar)


/*******************************************************************************
EXPORT
*******************************************************************************/

	wdrexport , ///
		title(Information and communication technology has had a mixed impact on learning) ///
		subtitle(Distribution of the effects of education technology on student learning, by type ) ///
		source(WDR 2018 team, using data from Muralidharan, Singh, and Ganimian (2016, annex 2).) ///
		chapter(7) figure(1)
