/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings

/*******************************************************************************
prep data
*******************************************************************************/

***	import
	use "${data}/Bloom and others 2015 means", clear
	
***	gen relative vars
	sum meanmgt
	gen relmgt = 100*(meanmgt/`r(max)')
	lab var relmgt "Relative management score"

***	archive data
	wdrarchive
	
/*******************************************************************************
graph
*******************************************************************************/

	graph hbar relmgt, ///
		over(country, des sort(relmgt)) ///
		bar(1 , color("$wdrscheme3")) ///
		ytitle("Percent") ///
		yscale(noline) ///
		ylabel(, glc(gs2) glp(shortdash) glw(thin) notick) ///
		graphregion(c(white)lc(white)lw(thick)margin(l-4 b-3 t-1 r-2)) ///
		plotregion(margin(t-3 b-3)) ///
		xsize(4) ysize(3) ///
		scale(1.5)
		
/*******************************************************************************
export
*******************************************************************************/

wdrexport , ///
	title(Schools vary significantly in management quality) ///
	subtitle(Average school management score by country, relative to top-performing country, participating countries) ///
	source(Bloom and others 2015.) ///
	note(The school management score is a combination of 14 basic management practices, each rated from 1 to 5. Schools with higher scores have more structured management practices.) ///
	chapter(7) figure(2) 
		
exit

