/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

*** WDR settings
	include wdrsettings

/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	load data
	use "${data}/STEP 2013-2015 workplace training participation", clear
	lab var country "Country"
	
***	fix country names
	replace country="Lao PDR" if country=="Laos"
	replace country="China (Yunnan)" if country=="Yunnan-China"
	
***	archive data
	wdrarchive

***	gen rank var
	sort country
	gen rank=_n

***	text country labels
	levelsof rank, local(ranks)
	sort rank
	foreach var in upsec_above level2_above ages25_44 {
		foreach rank of local ranks {
			sum `var' if rank==`rank'
			if `r(N)'==0 {
				local `var'labels ``var'labels' `rank' "   (no data)"
				}
			if `r(N)'==1 {
				local `var'labels ``var'labels' `rank' "`=country[`rank']'"
				}
			}
			}
		
/*******************************************************************************
GRAPH
*******************************************************************************/
		
***	set graph options
	local gopts graphregion(c(white)lc(white)lw(thick)) ///
				ylabel(#5, glc(gs2) glp(shortdash) glw(thin)) ///
				bar(1 , color("$wdrscheme1")) ///
				bar(2 , color("$wdrscheme3")) 
	local legopts region(c(none)margin(l-5)) c(1) symx(5) symy(3) pos(7)
	local titopts bexpand just(left) size(medsmall)
	
graph hbar  ages25_44 ages15_24	 , ///
		over(rank,  relabel(`ages25_44labels')) /// over(rank, label(nolabel)) ///
	title("{bf:a. By age}", `titopts') ///
	ytitle(Percent) ///
	legend(	 ///
		 `legopts' ///
		label(1 "Ages 25–44") ///
		label(2 "Ages 15–24") ///
		) ///
	`gopts' ///
	name(ages)	
	
	
graph hbar  level2_above level1_below, ///
	over(rank,  relabel(`level2_abovelabels')) /// over(rank, label(nolabel)) ///
	title("{bf:b. By reading proficiency}", `titopts') ///
	ytitle(Percent) ///
	legend(	 ///
	`legopts' ///
		label(1 "Level 2 and above") ///
		label(2 "Level 1 and below") ///
		) ///
	`gopts' ///
	name(proficiency)	

graph hbar  upsec_above lowsec_below, ///
	over(rank,  relabel(`upsec_abovelabels')) /// over(rank, label(nolabel)) ///
	title("{bf:c. By education}", `titopts') ///
	ytitle(Percent) ///
	legend(	 ///
		`legopts' ///
		label(1 "Upper secondary and above") ///
		label(2 "Lower secondary and below") ///
		) ///
	`gopts' ///
	name(education)
	
	
graph combine  ages proficiency education	, r(1) xcommon graphregion(c(white)lc(white)lw(thick)) imargin(0 0 0 0) name(combo, replace)
graph draw combo, xsize(6.5) ysize(4) name(final, replace)

/*******************************************************************************	
EXPORT
*******************************************************************************/
	
	wdrexport , ///
		title(Few benefit from workplace training, and those that do tend to already have better literacy or education) ///
		subtitle(Workplace training participation in last 12 months, circa 2011–14) ///  
		source(WDR 2018 team, using data from STEP Skills Measurement Programme  (microdata.worldbank.org/index.php/catalog/step/about ).) ///
		note(Respondents were asked, In the past 12 months, have you participated in any training courses, such as work-related training or private skills training, that lasted at least 5 days/30 hours (not part of the formal educational system)? Low proficiency is defined as levels 1 and below on the literacy assessments, and indicates limited understanding of texts. Medium to high proficiency is defined as levels 2 and above and indicates the ability to integrate, evaluate, and interpret information from a variety and complexity of text materials.) ///
		chapter(8) figure(1)
		
exit
