/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	import data
	use "${data}/UIS 2010 vocational and general education", clear
	lab var region "Region"

***	archive data
	wdrarchive
	
***	encode regions
	sort region
	encode region, gen(reg)
	
***	wrap labels & encode 
	preserve
	splitstring region
	replace region_line1=trim(region_line1)
	replace region_line2=trim(region_line2)
	sort reg
	levelsof reg, local(regs)
	foreach reg of local regs {
		local regionlabels `regionlabels' `reg' `""`=region_line1[`reg']'" "`=region_line2[`reg']'""'
		}
	restore
	
***	fix rounding errors for aesthetics 
	foreach level in up lo {
		replace `level'sec_left= 100- (`level'sec_vocational +`level'sec_general )
		}
	
***	reshape
	rename losec_* *Lower
	rename upsec_* *Upper
	reshape long general left vocational, i(region reg) j(level) str

/*******************************************************************************
graph
*******************************************************************************/	
	
graph bar (asis) vocational general  left , ///
	over(level, label(labsize(small))) ///
	over(reg, gap(*.75) relabel(`regionlabels') label(labsize(small))) ///
	stack nofill ///
	bar(1 , color("$wdrscheme1")) ///
	bar(2 , color("$wdrscheme6")) ///
	bar(3 , color("$wdrscheme3")) ///
	ytitle(Percent) ///
	ylabel( , angle(h) glc(gs2) glp(shortdash) glw(thin) notick labgap(1) ) ///
	yscale(noline) ///
	legend(region(c(none)) ///
		label(1 "Enrolled in vocational education") ///
		label(2 "Enrolled in general education") ///
		label(3 "Left the school system") ///
		r(1) ///
		order(3 2 1) ///
		symx(3) symy(3) ///
		)  ///
	xsize(6.5) ysize(3.5) ///
	graphregion(c(white)lc(white)lw(thick))
	
/*******************************************************************************
export
*******************************************************************************/
	
	wdrexport , ///
		title(Most vocational training students enroll during upper secondary) ///
		subtitle(Gross enrollment rates in general education and TVET, lower and upper secondary students (circa 2010)) ///
		source(WDR 2018 team, using data from UIS (2016).) ///
		chapter(8) figure(2)
exit

