/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
load and manipulate data
*******************************************************************************/

***	import and trim
	use "${data}/ASER UWEZO USAID shortfalls start early", clear

***	archive
	foreach subject in reading math {
		preserve
		keep country `subject' 
		drop if `subject'==.
		local panelttl : var label `subject'
		wdrarchive, title(`panelttl')
		restore
		}
		
***	reshape
	rename (math reading) zeroscore=
	reshape long zeroscore, i(country) j(subject) str
	drop if zeroscore==.
	
***	fix strings
	replace subject="mathematics" if subject=="math"
	replace subject=proper(subject)

***	gen sort figures (for relative sizing)
	gen 	aux_subject=1 if subject=="Reading"
	replace aux_subject=2 if subject=="Mathematics"
	gsort aux_subject -zeroscore
	gen zero=0
	gen sort=_n+aux_subject-1
	format zeroscore %3.0fc

	
/*******************************************************************************
GRAPH
*******************************************************************************/

*** identify all subjects
	levelsof subject, local(subjects)

***	set titles
local Mathematics_ttl "b. Grade 2 students who could not" "    perform two-digit subtraction"
local Reading_ttl "a. Grade 2 students who could not read a single" "    word of a short text"

*** set code for titles
	tokenize `c(alpha)'
	local graphno 0
	foreach subject of local subjects {
		local ++graphno
		sum sort if subject=="`subject'"
		local ttlx=`r(min)'-.5
		local ttl `ttl' text(111 `ttlx' "``subject'_ttl'", placement(e) size(medium) just(left))
		}

***	graph
	twoway ///
		(bar zeroscore sort, barwidth(.75) color("${wdrscheme1}") fi(100) ) ///
		(scatter zero sort, mlabel(country) mlabsize(medsmall) mlabangle(45) mlabpos(8) mlabgap(*.5) m(none) mlabc(gs0) ) ///
			, ///
			xscale(noline) xlabel(none) xtitle("") ///
			legend(off) ///
			ytitle("Percent") ///
			ylabel(0(20)100, notick angle(h) glc(gs2) glp(shortdash) glw(thin) labgap(2)) ///
			yscale(noline) ///
			graphregion(c(white)lc(white)lw(thick)margin(b+15 t+10)) ///
			yline(0, lc(black)) ///
			`ttl' ///
			xsize(6.5) ysize(2.75) ///
			scale(1.3)

/*******************************************************************************
EXPORT
*******************************************************************************/
		
wdrexport , ///
	title(Shortfalls in learning start early) ///
	subtitle(Percentage of grade 2 students who could perform simple reading or math tasks, selected countries) ///
	source(WDR 2018 team, using reading and mathematics data for Kenya and Uganda from Uwezo, Annual Assessment Reports, 2015 (www.uwezo.net/); reading and mathematics data for rural India from ASER Centre (2017); reading data for all other countries from U.S. Agency for International Development (USAID), Early Grade Reading Barometer, 2017, accessed May 30, 2017 (www.earlygradereadingbarometer.org/); and mathematics data for all other countries from USAID/RTI Early Grade Mathematics Assessment intervention reports, 2012–15 (shared.rti.org/sub-topic/early-grade-math-assessment-egma).) ///
	note(These data typically pertain to selected regions in the countries and are not necessarily nationally representative. Data for India pertain to rural areas.) ///
	chapter(0) figure(1)
	
exit

