/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREP DATA
*******************************************************************************/

***	load and trim
	use "${data}/Bloom and others 2014 management capacity", clear
	
***	data to archive 
	tempfile data_to_archive
	save `data_to_archive'
		
***	set locals
	levelsof country, local(countries)
	local linelook lc(gs2) lp(solid) lw(medium)
	local halfwidth .2
	local estimatepoints 100
	
***	generate sort order & country labels
	preserve
	cap keep if sector=="Education"
	bysort country: egen meanmgt= mean(management)
	keep country meanmgt
	duplicates drop
	egen rank= rank(meanmgt)
	merge m:1 country  using "${data}/class", keepusing(incomegroup) keep(1 3) nogen
	gen ig=incomegroup
	recode ig (1=1) (2/3=2) (4=3)
	egen ctry = axis(rank), label(country)
	keep ctry country ig
	tempfile ctry
	save `ctry'
	restore
	merge m:1 country using `ctry', nogen

***	gen xlines
	sum ctry
	local maxctry=`r(max)'
	forvalues x=1/5{
		local xlines `xlines' xline(`x', `linelook') 
		local xtexts `xtexts' text(2 `x' "`x'", size(vhuge))
		}	

/*******************************************************************************
GRAPH
*******************************************************************************/
	
***	set graph options
	local rightmargin 65
	local leftmargin 5
	local col1 "${wdrscheme7}"
	local col2 "${wdrscheme1}"
	
***	set up labels
	foreach sector in Manufacturing Education {
		preserve
		kdensity management if sector=="`sector'" & ctry==1, gen(`sector'_x `sector'_d) nograph
		egen `sector'_max =max(`sector'_d)
		gen `sector'_d_match		=1000* round(`sector'_d,.001)
		gen `sector'_max_match 	=1000* round(`sector'_max,.001)
		sum `sector'_x if `sector'_max_match ==`sector'_d_match
		local slx =`r(mean)'
		sum `sector'_d if `sector'_max_match ==`sector'_d_match
		local sly =`r(mean)'
		local sector_label1 `sector_label1' text(`sly' `slx' "`sector'", size(huge) placement(ne) color(gs1))
		restore
		}
	
***	x-axis title and labels for education and manufacturing graph with no income groups
	sum ctry
	local noctry = `r(max)'+1

	twoway ///
		(bar management ctry if ctry==`noctry' & sector=="Education" & ig==1, fc("`col1'") lc("`col1'") fi(100)) ///
		(bar management ctry if ctry==`noctry' & sector=="Manufacturing" & ig==2, fc("`col2'") lc("`col2'") fi(100)) ///
			, ///
		ytitle("") yscale( noline) ylabels(none, nogrid ) /// 
		xscale(range(1 4) noline) xlabels(none) ///
		legend(	///	
			region(c(none)m(r-`rightmargin' l+`leftmargin' t+3)) ///
			r(1) ///
			symy(3) symx(7) ///
			label(1 "Education") ///
			label(2 "Manufacturing") ///
			size(vhuge) ///
			) ///			
		`xtexts' ///	
		xtitle("Management score",  margin(t+15) size(vhuge) color(black)) ///
		graphregion(c(none)lc(white)lw(thick) m(r+`rightmargin' l-`leftmargin')) /// 
		fysize(20) ///
		name(h`noctry', replace)
	
***	loop over countries to graph
	foreach country of local countries {
		sum ctry 	if country=="`country'"
		local graphno =`r(mean)'
		sum ig		if country=="`country'"
		local ig=`r(mean)'
		twoway  /// 		(histogram management if country=="`country'" & sector=="Manufacturing" 	/*& std_management<2.6 & std_management>-2.6 	*/, lc("`col2'") lw(thick) fc(none) w(.1)	) ///
		(histogram management if country=="`country'" & sector=="Education" 	/*& std_management<2.6 & std_management>-2.6 	*/, lc("`col1'") lw(thick) fc(none) w(.1)	) ///
		(kdensity management if country=="`country'" & sector=="Manufacturing" 	/*& std_management<2.6 & std_management>-2.6 	*/, bw(`halfwidth') lc("`col2'") lw(vthick) ) ///
		(kdensity management if country=="`country'" & sector=="Education" 		/*	& std_management<2.6 & std_management>-2.6 	*/ , bw(`halfwidth') lc("`col1'") lw(vthick)) /// 
			, ///
		ytitle("") yscale( noline) ylabels(none, nogrid ) /// 
		xtitle("") xscale(noline) xlabels(none) ///
		legend(off) ///
		`xlines' ///
		text(.60 5.05 "`country'", color(black) size(vhuge) placement(e) bexpand) /// 
		graphregion(c(none)lc(white)lw(thick) m(r+`rightmargin' l-`leftmargin' b-4 t-6)) /// 
		name(f`graphno', replace)
		}	
	
***	combine graphs
	graph combine f1 f2 f3 f4 f5 f6 f7 f8 f9 f10 f11 h12, xcommon ycommon c(1) graphregion(c(white)lc(white)lw(thick)margin(b-1))  name(fcombo, replace) 
	graph draw fcombo, xsize(3.25) ysize(8.5) scale(1.1) name(f_gr, replace)
	
/*******************************************************************************
EXPORT
*******************************************************************************/	

***	chapter 0
	use `data_to_archive', clear
	wdrarchive
	wdrexport , ///
		title(Management capacity is low in schools in low- and middle-income countries) ///
		subtitle(Distribution of management scores by sector, participating countries) ///
		source(WDR 2018 team with data from WDI 2017; Bloom and others 2014; Bloom and others 2015; and Lemos and Scur 2016, with updates.) ///
		note(The underlying distributions for the education data are shown as bars; for both sectors, the smoothed distributions are shown as curves. The indexes are constructed from the nine items that are comparable across sectors. Data on manufacturing are not available for Haiti.) ///
		chapter(0) figure(10)

*** chapter 3
	use `data_to_archive', clear
	wdrarchive
	wdrexport , ///
		title(Management capacity is low in schools in low- and middle-income countries) ///
		subtitle(Distribution of management scores by sector, participating countries) ///
		source(WDR 2018 team with data from WDI 2017; Bloom and others 2014; Bloom and others 2015; and Lemos and Scur 2016, with updates.) ///
		note(The underlying distributions for the education data are shown as bars; for both sectors, the smoothed distributions are shown as curves. The indexes are constructed from the nine items that are comparable across sectors. Data on manufacturing are not available for Haiti.) ///
		chapter(3) figure(12) 
					
exit
