/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	import data
	use "${data}/UNESCO 2016 representative learning data", clear
	
***	encode category	
	preserve
	drop if category=="World"
	bysort 	category:	egen axis=mean(pct)
	keep category axis
	duplicates drop
	gsort -axis
	replace axis=_n
	tempfile axis
	save `axis'
	restore
	merge m:1 category using `axis', nogen
	sum axis
	replace axis=`r(max)'+1 if axis==.
	egen	region 		= axis(axis), label(category)
	drop axis

***	pull region labels
	preserve
	keep region category
	duplicates drop
	splitstring category
	levelsof region, local(regions)
	foreach region of local regions {
		sort region
		local tit_`region' `region' `""`=category_line1[`region']'" "`=category_line2[`region']'""'
		local regiontitles `regiontitles' `tit_`region''
		}
	restore
	
***	reshape wide
	reshape wide pct, i(category grade region) j(subject) str
	
***	encode grade
	gen 	axis 		= 1 if grade=="primary"
	replace axis 		= 2 if grade=="lower secondary"
	egen 	level		= axis(axis), label(grade)
	drop 	axis
	
*** rename and reorder
	order category region grade level 
	rename pct* *
	
***	label vars
	lab var mathematics "Percent of countries with mathematics data to monitor progress toward SDG learning goals"
	lab var reading "Percent of countries with reading data to monitor progress toward SDG learning goals" 

***	archive data
	preserve
	keep category grade reading mathematics
	wdrarchive
	restore

/*******************************************************************************
GRAPH
*******************************************************************************/

graph bar mathematics reading, ///
	over(level, relabel(1 "Primary" 2 `""Lower" "secondary""')) ///
	over(region, relabel(`regiontitles')) ///
	ylabel(0(20)100, glc(gs2) glp(shortdash) glw(thin) angle(h) notick) ///
	yscale(range(0 100) noline) ///
	bar(1, color("$wdrscheme4")) ///
	bar(2, color("$wdrscheme1")) ///
	legend(region(c(none)) label(1 "Mathematics") label(2 "Reading") symx(3) symy(3))  ///
	graphregion(c(white)lc(white)lw(thick)) ///
	ytitle(Percent) ///
	xsize(6.5) ysize(3)
	
/*******************************************************************************
EXPORT
*******************************************************************************/
	
	wdrexport , ///
		title(Many countries lack information on learning outcomes) ///
		subtitle(Percentage of countries with data to monitor progress toward the Sustainable Development Goals for learning by the end of primary or lower secondary school) ///
		source(UIS 2016.) ///
		note(Regional groupings follow UNESCO definitions.) ///
		chapter(0) figure(12)		
		
exit
