/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
manipulate data
*******************************************************************************/

***	load data
	use "${data}/PASEC 2017", clear
	order country, first
	
*** fix country names
	replace country="Congo, Rep." 	if country=="Congo"
	replace country="Cote d'Ivoire" if country=="Côte d’Ivoire"

***	archive
	wdrarchive
	
***	rescale level 1
	replace l1=-l1
	
***	replace strings
	replace gender="F" 		if gender=="Girls"
	replace gender="M" 		if gender=="Boys"
	replace status="Poor"	if status=="Poorest 20%"
	replace status="Rich"	if status=="Richest 20%"

***	gen sort variable
	bysort country: egen sort=mean(l1)
	preserve
	keep country sort
	duplicates drop
	sort sort
	replace sort=_n
	levelsof sort, local(sorts)
	sort sort
	foreach sort of local sorts {	
		local country`sort' `=country[`sort']'
		}
	tempfile sort
	save `sort'
	restore
	drop sort
	merge m:1 country using `sort', nogen
	
***	reorder
	rename l? pct?
	order country status gender sort pct1 pct2 pct3
	sort sort status gender

/*******************************************************************************
GRAPH
*******************************************************************************/

***	set options
	local gopts lw(thin) lp(shortdash) lc(gs4) 
	local mb -20
	local topts placement(w) size(small)
	local lgnd label(1 "Not competent") label(2 "Low competency") label(3 "High competency")
	local subjects Reading Mathematics
	levelsof status,  	local(statuses)
	tokenize `c(alpha)'
	local i=0
	levelsof sort, local(sorts)
	local text1 text(-100 `mb' "100", `topts') text(-50 `mb' "50", `topts') text(0 `mb' "0", `topts') text(50 `mb' "50", `topts') text(100 `mb' "100", `topts') 
	local ytit1 ytitle("Percentage of students", size(medsmall) margin(l-10) color(black))
	
	
***	graph
	foreach sort of local sorts {
	local ++i
	graph bar pct1 pct2 pct3 if sort==`sort', ///
		over(gender, axis(noline) gap(20) label(labsize(small) labgap(*.05) ) )  /// 
		over(status, axis(noline) gap(20) label(labsize(small) labgap(*.05) ) )  /// 
		outergap(0) ///
		stack nofill   ///
		legend(`lgnd' r(1) region(c(none)m(t+1))  symx(2) symy(2) size(small)) ///
	graphregion(c(none)lw(thick)lc(none)) ///
	plotregion(margin(l-1.5 r+4)) ///
		bar(1, col(${wdrscheme7})) ///
		bar(2, col(${wdrscheme5})) ///
		bar(3, col(${wdrscheme1})) ///
	 yline(-100	, `gopts') ///
	 yline(-75	, `gopts') ///
	 yline(-50	, `gopts') ///
	 yline(-25	, `gopts') ///
	 yline(0	, lw(thin) lp(solid) lc(gs4) ) ///
	 yline(25	, `gopts') ///
	 yline(50	, `gopts' )  ///
	 yline(75	, `gopts') ///
	 yline(100	, `gopts' ) ///
		ylabels(none, nogrid) ///
		`ytit`i'' `text`i'' ///
	yscale(r(-100 100) noline ) ///
	title(`"`country`sort''"', pos(6) color(black) bexpand size(medsmall) margin(l-5.5)) ///
		name(g`i', replace)
	local test_combo `test_combo' g`i'
	}


***	combine graphs
	grc1leg `test_combo', ///
		graphregion(c(white)lw(thick)lc(none)m(l+10 r-5)) ///
		iscale(.9) imargin(-6 -6 0 0) ///
		r(1) ycommon ///
		leg(g2) ///
		name(comp_tests, replace) 

***	resize graph
	graph draw comp_tests, xsize(6.5) ysize(3) scale(1.1) name(pasec_inequal, replace) 

***	drop graphs
	graph drop g?
	graph drop comp_tests
	
/*******************************************************************************
EXPORT
*******************************************************************************/
	
	wdrexport , ///
		title(Children from poor households in Africa typically learn much less) ///
		subtitle(Percentage of grade 6 PASEC test takers in 2014 who scored above (blue) and below (red) the sufficiency level on reading achievement: poorest and richest quintiles by gender, selected countries) ///
		source(WDR 2018 team, using data from World Bank (2016b).) ///
		note(SSocioeconomic quintiles are defined nationally. “Not competent” refers to levels 0–2 in the original coding and is considered below the sufficiency level for school continuation; “low competency” refers to level 3; and “high competency” refers to level 4. PASEC = Programme d’Analyse des Systèmes Educatifs de la Confemen.) ///
		chapter(0) figure(3)

exit

