/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	load data
	use "${data}/MICS 2012", clear

*** rescale
	foreach var in mean high low {
		replace `var'=100*`var'
		}

*** convert ages to years and drop less than 3 years
	gen agey = agem/12
	order agey, after(agem)
	drop if agem<36
	
***	archive
	preserve
	decode quintile, gen(quin)
	drop quintile
	rename quin quintile
	tempfile datatoarchive
	save `datatoarchive'
	restore
	
/*******************************************************************************
GRAPH
*******************************************************************************/

***	levels of graph codes
	levelsof code, local(codes)
	levelsof quintile, local(quintiles)

*** set locals for graphing
	local CAF_ytit "Percentage of children"
	local KAZ_ytit ""
	local TUN_ytit ""
	local CAF_tit "Central African Republic"
	local KAZ_tit "Kazakhstan"
	local TUN_tit "Tunisia"
	local labsz medium

***	code grid lines
	local gopts lc(gs6) lw(vvthin) lp(solid)
	forvalues y=0(20)100 {
		local grids `grids' yline(`y', `gopts') text(`y' 2.9 "`y'", box bc(white) m(r+2))
		}

***	loop for graph codes
	foreach code of local codes {
		foreach quintile of local quintiles {
			local `code'_scat ``code'_scat' (line mean agey if code=="`code'" & quintile==`quintile', lc("${wdrscheme`quintile'}") lwidth(thick) lp(solid))
			local `code'_scat ``code'_scat' (line high agey if code=="`code'" & quintile==`quintile', lc("${wdrscheme`quintile'}") lwidth(thick) lp(shortdash))
			local `code'_scat ``code'_scat' (line low  agey if code=="`code'" & quintile==`quintile', lc("${wdrscheme`quintile'}") lwidth(thick) lp(shortdash))
			}
			}

***	graph
	foreach code of local codes {
	twoway 	``code'_scat'	, ///
			aspectratio(1) ///
		graphregion(c(white)lc(white)lw(thick)) ///
		`grids' ///	
		legend( ///
			region(c(none)) ///
			order (6 3 4 1) ///
			label(1 "95% confidence interval") ///
			label(3 "Poorest quintile") ///
			label(4 "95% confidence interval") ///
			label(6 "Richest quintile") ///
			bexpand symx(5) symy(2) ///
			r(2) ///
			) ///
		xtitle("Age") ///
			ytitle("``code'_ytit'", margin(r+5)) ///
		xlabels(,tlc(gs2) ) ///
		xscale(noline) ///
		yscale(noline) ///
		title("{bf:``code'_tit'}", color(black) size(medium) bexpand just(left)) ///
		ylabels(none, notick nogrid) ///
						name(`code', replace) 
		}			
	
***	combine graphs			
	grc1leg CAF KAZ TUN, r(1) ycommon 	graphregion(c(white)lc(white)lw(thick)) iscale(1) imargin(0 4 0 0) name(combo)
	graph display combo, xsize(6.5) ysize(2.75) scale(*1.1)
			
/*******************************************************************************
EXPORT
*******************************************************************************/			

***	export for chapter 0
	use `datatoarchive', clear
	wdrarchive
	wdrexport , ///
		title(Socioeconomic gaps in cognitive achievement grow with age--even in preschool years) ///
		subtitle(Percentage of children ages 3-5 who can recognize 10 letters of the alphabet, by wealth quintile, selected countries) ///
		source(WDR 2018 team, using data from Multiple Indicator Cluster Surveys (mics.unicef.org/). Data are for 2010 for Central African Republic, 2010–11 for Kazakhstan, and 2012 for Tunisia.) ///
		chapter(0) figure(8)

***	export for chapter 3			
	use `datatoarchive', clear
	wdrarchive
	wdrexport , ///
		title(Socioeconomic gaps in cognitive achievement grow with age--even in preschool years) ///
		subtitle(Percentage of children ages 3-5 who can recognize 10 letters of the alphabet, by wealth quintile, selected countries) ///
		source(WDR 2018 team, using data from Multiple Indicator Cluster Surveys (mics.unicef.org/). Data are for 2010 for Central African Republic, 2010–11 for Kazakhstan, and 2012 for Tunisia.) ///
		chapter(3) figure(9)

exit
