/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings

/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	import and trim
	use "${data}/Bold and others 2016 teacher absences", clear
	sum year
	local minyr =`r(min)'
	local maxyr =`r(max)'	

***	archive
	wdrarchive

***	generate new label
	tostring year, replace
	replace country = country+" "+year

***	gen sort variable
	egen sort=rowmean(school_absence classroom_absence)

/*******************************************************************************
GRAPH
*******************************************************************************/

	graph bar  classroom_absence school_absence,  ///
		over(country, sort(classroom_absence) des ///
				label(angle(45))) ///
		graphregion(c(white)lc(white)lw(thick)) ///
			ylabel(0(20)60, angle(h) glc(gs2) glp(shortdash) glw(thin) notick) ///
			yscale(noline) ///
			ytitle("Percent") ///
			bargap(-50) ///
		legend( /// 	
			title("Teachers absent from the:", size(medsmall) just(left) color(black) pos(9) margin(r+2) ) /// 
			label(2 "school")  /// 
			label(1 "classroom") /// 
			region(c(none) margin(t-5))  ///
		symx(3) symy(3) ///
		keygap(*.5) ///
		colgap(*.75) ///
		c(1) pos(6) ///
		) ///
		bar(1 , col("${wdrscheme1}") ) ///
		bar(2 , col("${wdrscheme5}") ) ///
		xsize(3) ysize(3) ///
		name(shortfalls, replace)
		
/*******************************************************************************
EXPORT
*******************************************************************************/

wdrexport , ///
	title(In Africa, teachers are often absent from school or from classrooms while at school) ///
	subtitle(Percentage of teachers absent from school and from class on day of an unannounced visit, participating countries) ///
	source(Bold and others 2017.) ///
	note(Absent from the classroom combines absences from school with absences from class among teachers who are at school. Data are from the World Bank’s Service Delivery Indicators (SDI) surveys (www.worldbank.org/sdi).) ///
	chapter(0) figure(9)

exit

