/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREP DATA
*******************************************************************************/

***	import data
	use "${data}/Nelson and others forthcoming brain tissue", clear

***	archive
	wdrarchive
	
/*******************************************************************************
GRAPH
*******************************************************************************/

***	reshape
	replace group="Never" if group=="Never stunted"
	reshape wide volume, i(type) j(group) str
	lab var volumeNever "Never stunted"
	lab var volumeStunted "Stunted"
	rename volume* *
	rename _all, lower
	
***	gen sort var
	gsort -never
	gen sort=_n

***	graph
graph bar never stunted, ///
	over(sort, ///
		relabel(4 `""Cerebral" "spinal fluid""' ///
				3 `""White" "matter""' ///
				2 `""Gray" "matter""' ///
				1 "Total" ///
		)) ///
	bar(1, color("$wdrscheme5")) ///
	bar(2, color("$wdrscheme3")) ///
	legend(region(c(none)) label(1 "Never stunted") label(2 "Stunted") ///
		symx(4) symy(4)) ///
	graphregion(c(white)lc(white)lw(thick)) ///
	ylabel(0(100)700, angle(h) glc(gs8) glp(shortdash) glw(thin) notick) ///
	ytitle("Volume (ml)") ///
	xsize(4) ysize(4) scale(1.2)

/*******************************************************************************
EXPORT
*******************************************************************************/

wdrexport , ///
	title(Severe deprivation affects brain structure and function from early on in life) ///
	subtitle(Volume of brain tissue, by stunting status) ///
	note(Data obtained from infants 2–3 months old in Dhaka, Bangladesh, using magnetic resonance imaging (MRI). Graph depicts two groups of infants: 18 stunted (malnourished) and 9 not stunted (not malnourished). Graph shows (from left to right) total amount of brain volume; total amount of gray matter, where most neural computations are performed; total amount of white matter, which transmits electrical signals between gray matter and affects brain function and learning (that is, the information pathways of the brain); and cerebral spinal fluid, which protects the brain and spinal cord from injury and infection and is generally involved in many aspects of brain health.) ///
	source(WDR 2018 team, using data from Nelson and others (2017).) ///
	chapter(2) figure(1) spotlight


exit
