/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	import data
	use "${data}/Evans and Popova 2016 and 3ie 2016 cumulative studies", clear

***	archive data
	wdrarchive

***	add marker labels
	gen mlabel=cumulative if year==2000 | year==2016
	
/*******************************************************************************
GRAPH
*******************************************************************************/

***	set options
	local thickness medium
	replace cumulative=count if cumulative==.
	gen previous = cumulative-count

***	graph
	twoway /// 
	(bar		cumulative year if mlabel==., fc("$wdrscheme5") lc("$wdrscheme5") lw(`thickness') fi(100) barwidth(.75)) ///
	(bar		previous year if mlabel==., fc(white) lc("$wdrscheme5") lw(`thickness') fi(100) barwidth(.75)) ///
	(bar 		cumulative year if mlabel!=., lc("$wdrscheme3") fc("$wdrscheme3") lw(`thickness') fi(100) barwidth(.75)) ///
	(scatter	cumulative year if mlabel!=., mlabel(mlabel) mlabsize(medsmall) mlabpos(12) m(none) mlabc("$wdrscheme3")) ///
		, ///
	graphregion(c(white)lc(white)lw(thick)) ///
	xscale(range(1980 2016) noline) ///
	xlabel(1980(6)2016, tlc(gs8) ) ///
	ylabel(, angle(h) notick glc(gs2) glp(shortdash) glw(thin) labgap(1.5)) ///
	yscale(noline) ///
	legend(off) ///
	yline(0, lw(thin) lc(black)) ///
	ytitle(Cumulative studies) ///
	xtitle(Year, margin(t+3)) ///
	xsize(5) ysize(3) ///
	scale(1.5) ///
	name(studies_bar, replace)

/*******************************************************************************
EXPORT
*******************************************************************************/

	wdrexport , ///
		title(Experimental and quasi-experimental studies of interventions to improve learning have mushroomed in recent decades) ///
		source(Evans and Popova 2016b; 3ie 2016.) ///
		chapter(4) figure(1) spotlight

exit
