/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	import data
	use "${data}/World Bank 2017 and ITU 2016", clear

***	archive data
	wdrarchive

/*******************************************************************************
GRAPH
*******************************************************************************/

***	pull stats
sum year
gen mlabel=category if year==`r(max)'

***	set commands
	preserve
	keep if category !="World"
	levelsof category, local(categories)
	local color=2
	foreach category of local categories {
		local ++color
		local internetscat `internetscat' 		(scatter internet year if category=="`category'", sort m(none) c(l) lw(thick) mlabel(mlabel) mlabgap(1) lc("${wdrscheme`color'}") mlabc("${wdrscheme`color'}") mlabsize(medsmall))
		local electricityscat `electricityscat'	(scatter electricity year if category=="`category'", sort m(none) c(l) lw(thick) mlabel(mlabel) mlabgap(1) lc("${wdrscheme`color'}") mlabc("${wdrscheme`color'}") mlabsize(medsmall))
		}
	restore

	local internetscat `internetscat' (scatter internet year if category=="World", sort m(none) c(l) lw(thick) mlabel(mlabel) mlabgap(1) lc("$wdrscheme1") mlabc("$wdrscheme1") mlabsize(medsmall))
	local electricityscat `electricityscat' (scatter electricity year if category=="World", sort m(none) c(l) lw(thick) mlabel(mlabel) mlabgap(1) lc("$wdrscheme1") mlabc("$wdrscheme1") mlabsize(medsmall))

***	set options
	local electricity_ylabs	ylabel(0(20)100, angle(h) glc(gs2) glw(thin) glp(shortdash) notick labgap(2) )
	local internet_ylabs 	ylabel(0(20)100, grid nolabels angle(h) glc(gs2) glw(thin) glp(shortdash) notick labgap(2) )
	local electricity_yttl ytitle("Percent") 
	local internet_yttl 	ytitle(" ", height(14))
	local electricity_ttl "a. Population with access to electricity"
	local internet_ttl "b. Population who use the internet"
	
***	graph
	foreach tech in internet electricity {
	twoway ``tech'scat' , ///	
	legend(off) ///
	``tech'_ylabs' /// 
	``tech'_yttl' ///
	yscale(range(0 100) noline ) ///
	xlabel(2005(3)2015) ///
	xtitle("Year", height(8)) ///
	xscale(noline) ///
	graphregion(c(white)lc(white)lw(thick)margin(r+2)) ///
	plotregion(margin(l+1 r+1)) ///
	xsize(5) ysize(3) ///
	scale(1.2) ///
	title("``tech'_ttl'", bexpand just(left) color(black) size(medium) margin(b+3)) ///
	name(`tech', replace)
	}

***	combine graphs
	graph combine electricity internet, r(1) graphregion(c(white)lc(white)lw(thick)margin(r+21)) imargin(0 0 0 0) xsize(6.5) ysize(3) scale(1.25)
	graph drop electricity internet
	
/*******************************************************************************
EXPORT
*******************************************************************************/

	wdrexport , ///
		title(Technology use has increased dramatically over the last decade--but remains low in many countries) ///
		subtitle(Percentage of population with access to electricity (2005–14) and who use the Internet (2005–15), by income group) ///
		source(WDR 2018 team, using data from World Bank (2017) for acess to electricy and ITU (2016) for internet users.) ///
		chapter(5) figure(1) spotlight

exit

