/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREP DATA
*******************************************************************************/

***	import data
	use "${data}/UNESCO 2015 education spending", clear
	
***	archive data
	wdrarchive
	
***	reshape data for graph
	rename percentage yr
	reshape wide yr, i(incomegroup denominator) j(year)

/*******************************************************************************
GRAPH
*******************************************************************************/

***	identify groups
	levelsof incomegroup, local(incomegroups)
	levelsof denominator, local(denominators)

***	graph
	tokenize `c(alpha)'
	local i=0
	foreach denominator of local denominators {
	local ++i
	graph bar yr1999 yr2012 if denominator=="`denominator'" , ///
		over(incomegroup, ///
			relabel(1 `"Low"' ///
			2 `""Lower" "Middle""' ///
			3 `""Upper" "Middle""' ///
			4 `"High"')) ///
		ylabel(0(5)15, angle(h) notick glc(gs8) glp(shortdash) glw(thin)) ///
		bar(1, color($wdrscheme1)) ///
		bar(2, color($wdrscheme3)) ///
		yscale(range(0 16)) ///
		ytitle("Percent") ///
		graphregion(c(white)lc(white)lw(thick)) ///
		legend(region(c(none)) symx(3) symy(3) r(1) label(1 "1999") label(2 "2012")) ///
		title("``i''. Government spending on education as a" "    percentage of `denominator'", bexpand just(left) size(medium)) ///
		name(g`i', replace) 
		 }
		 
***	combine graphs
	grc1leg g1 g2, graphregion(c(white)lc(white)lw(thick)) name(combo) iscale(1.05)
	graph draw combo, xsize(6.5) ysize(3) scale(1.1)
	graph drop g1 g2
	
/*******************************************************************************
EXPORT
*******************************************************************************/

wdrexport , ///
	title(Governments devote a large share of their budgets to education) ///
	subtitle(Median government spending on education, by income group (1999 and 2012)) ///
	source(UNESCO (2015).) ///
	note(GNP = gross national product) ///
	chapter(6) figure(1) spotlight

exit
