/*******************************************************************************
Bradley Larson (Larson.Brad@gmail.com)
split a string into two lines
intended to wrap labels for graphs
*******************************************************************************/

capture program drop splitstring
program define splitstring
version 14
syntax varname (string), [Lines(integer 2)]

*** parse options
	local splitvar `varlist' 	// the string to be split
	local lines `lines' // the number of lines  (must be 2 for now)
	levelsof `splitvar', local(cases)
	
***	exit if lines do not equal 2 (hopefully temp)
	if `lines' !=2 {
		exit 100
		}
	
***	preserve
	preserve
	
***	create a separate dataset to work with
	keep `splitvar' 
	duplicates drop
	tempfile splitfile
	save `splitfile'

***	loop over each of the strings (cases) to be split
	foreach case of local cases { // open case loop
		
***	load data and trim to the string to be split
	use `splitfile', clear
	qui keep if `splitvar'=="`case'"
	qui keep `splitvar' 
	
***	split the string & count the constituent elements
	qui split `splitvar', p(" ")
	local maxelements = `r(nvars)'

***	create new varibles where we will concatenate the strings
	forvalues line=1/`lines' {
		qui gen `splitvar'_line`line'=""
		}
		
***	expand observations to accomodate all possible concatenations
	qui expand =`maxelements'
	gen str_option=_n
	
***	generate all permutaions (starting here i explicitly refer to lines 1 and 2, because i don't know how to expand this to more lines)
	forvalues element=1(1)`maxelements' {
		local nextelement=`element'+1
	
	*** concatenate line 1
		forvalues line1=1(1)`element' {
			qui replace `splitvar'_line1 = `splitvar'_line1+ " "+`splitvar'`line1' if `element'==str_option
			}
			
	*** concatenate line 2	
		forvalues line2=`nextelement'(1)`maxelements' {
			qui replace `splitvar'_line2 = `splitvar'_line2+ " "+`splitvar'`line2' if `element'==str_option
			}
		}
		
***	calculate the difference in the length of strings for each permutation
	qui gen str_difference =.
	forvalues element=1(1)`maxelements' {
		qui replace str_difference = abs(length(`splitvar'_line1) - length(`splitvar'_line2))
		}
		
***	keep the permutation with the smallest difference
	qui egen 	str_mindifference = min(str_difference)
	qui keep if str_mindifference == str_difference
	qui sum str_difference
	if `r(N)' >1 {
		gsort -`splitvar'_line1
		keep in 1
		}
	
***	trim and merge
	qui keep `splitvar' `splitvar'_line?
	qui merge 1:1 `splitvar' using `splitfile', nogen
	qui save `splitfile', replace
	}

*** restore
	restore
	
***	merge results
	merge m:1 `splitvar' using `splitfile', nogen
	
end

