/*******************************************************************************
Bradley Larson (Larson.Brad@gmail.com)
*******************************************************************************/

capture program drop wdrexpor
program define wdrexport, rclass
version 14
syntax  , Title(passthru) SOurce(passthru) Chapter(integer) Figure(real)   [SUbtitle(passthru) NOTe(passthru) spotlight box quietly]

/*******************************************************************************
PARSE TITLE, SUBTITLE, SOURCE, AND NOTE FROM OPTIONS
*******************************************************************************/

if "`title'"!="" {
		local formaltitle=subinstr("`title'","title(","",1)
		local formaltitle="`formaltitle'"+"@%*REMOVE"		
		local formaltitle=subinstr("`formaltitle'",")@%*REMOVE","",.)
		}
	if "`subtitle'"!="" {
		local formalsubtitle=subinstr("`subtitle'","subtitle(","",1)
		local formalsubtitle="`formalsubtitle'"+"@%*REMOVE"		
		local formalsubtitle=subinstr("`formalsubtitle'",")@%*REMOVE","",.)
		}
	if "`source'"!="" {
		local figuresource=subinstr("`source'","source(","",1)
		local figuresource="`figuresource'"+"@%*REMOVE"		
		local figuresource=subinstr("`figuresource'",")@%*REMOVE","",.)
		}	
	if "`note'"!="" {
		local figurenote=subinstr("`note'","note(","",1)
		local figurenote="`figurenote'"+"@%*REMOVE"		
		local figurenote=subinstr("`figurenote'",")@%*REMOVE","",.)
		}	
	if "`figure'"!="" {
		local figurenumber=`figure'
		}
	if "`chapter'"!="" {
		local chapternumber=`chapter'
		}
	if "`namelist'"!="" {
		local givenstub="`namelist'"
		}

/*******************************************************************************
DETERMINE FIGURE CLASS
*******************************************************************************/

*** figure class can't be BOX and SPOTLIGHT
if "`spotlight'"!="" {
	if "`box'"!="" {
		noi di as error _newline(2) "{phang}You cannot specify both Spotlight and Box figure types. Choose a maximum of one non-standard figure type. Specifying neither will export the graph as a standard chapter figure.{p_end}"
		exit 198
		} 
		}
*** figure class can be one or the other
if "`spotlight'"!="" & "`box'"=="" {
	local figureclass "`spotlight'"
	}
if "`box'"!="" & "`spotlight'"=="" {
	local figureclass "`box'"
	}
***	or figure class can be neither, and thus be a standard chapter figure
if "`spotlight'"=="" & "`box'"=="" {
	local figureclass "standard"
	}

/*******************************************************************************
DETERMINE FILE NAME
*******************************************************************************/

*** make figure number path-friendly, converting periods to underscores
	local friendlyfigure =subinstr("`figurenumber'",".","_",.)
	
*** make chapter number reference-friendly, replacing chapter 0 with chapter O
	if "`chapter'"=="0" {
		local friendlychapter="O"
		}
	else {
		local friendlychapter ="`chapter'"
		}

*** concatenate for standard figures
	if "`figureclass'"=="standard" {
		local root "`friendlychapter'-`friendlyfigure'"
		local filenamestub "Figure `root'"		
		}

*** concatenate for box figures
	if "`figureclass'"=="box" {
		local root "`friendlychapter'-`friendlyfigure'"
		local filenamestub "Box Figure `root'"		
		}

*** concatenate for spotlight figures
	if "`figureclass'"=="spotlight" {
		local root "S`friendlychapter'-`friendlyfigure'"
		local filenamestub "Figure `root'"
		}


/*******************************************************************************
SAVE FIGURE ID VALUES TO A DATA FILE IN OUTPUT FOLDER
*******************************************************************************/

***	fix punctuation in reference string
	local reference =  subinstr("`filenamestub'","_",".",.)
	local reference =  subinstr("`reference'","-",".",.)

***	populate metadata
	preserve
	clear
	qui set obs 1
	qui gen figureclass	="`figureclass'"
	qui gen reference	="`reference'"
	qui gen root		="`root'"
	qui gen chapternumber	=`chapternumber'
	qui gen figurenumber	=`figurenumber'
	qui gen title		="`formaltitle'"
	qui gen subtitle	="`formalsubtitle'"
	qui gen source		="`figuresource'"
	qui gen note		="`figurenote'"
	qui gen outputpath	="`outputpath'"
	qui gen report_url 	="http://www.worldbank.org/wdr2018"
	qui gen data_url 	="http://bit.do/WDR2018-Fig_`root'"
	qui save 		"${output}/`filenamestub' meta", replace
	restore

/*******************************************************************************
SAVE GRAPHICS FILES TO OUTPUT FOLDER 
*******************************************************************************/

***	save graphs
	local figure_types emf eps png  //	png emf  ps pdf eps tif wmf 
	foreach figure_type of local figure_types {
		qui graph export "${output}/`filenamestub'.`figure_type'", replace
		}


/*******************************************************************************
SAVE DATA FILE TO OUTPUT FOLDER
*******************************************************************************/

***	load and transform meta file to create standard header for data folder
	preserve	
	use "${output}/`filenamestub' meta", clear

***	generate reference number from chapter and figure numbers
	qui tostring _all, replace
	
***	trim and rename vars
	drop root chapternumber figurenumber outputpath figureclass 
	rename _all, proper
	rename _all cat_=

***	reshape
	qui gen X=1
	qui reshape long cat_, i(X) j(value) str
	qui set obs 8

***	order observations and generate labels for production
	qui replace X=1 if value =="Reference"
	qui replace X=2 if value =="Title"
	qui replace X=3 if value =="Subtitle"
	qui replace X=4 if value =="Source"
	qui replace X=5 if value =="Note"
	qui replace X=6 if value =="Report_Url" 
	qui replace X=7 if value =="Data_Url"
	qui sort X
	qui drop X

***	fix strings for URL names
	qui replace value="Data URL" if value =="Data_Url"
	qui replace value="Report URL" if value =="Report_Url" 

***	establish CSV file for export
	qui export delimited "${output}/`filenamestub' data.csv", replace novarnames
	restore

***	determine if data has been archived, and prep for CSV export if so
	confirm file "wdrdataarchivemetadata.dta"

***	set up handle for data export
	tempname dataexport
	file open `dataexport' using "${output}/`filenamestub' data.csv",  append write 

***	export null message if no data was archived
if _rc!=0 {
	file write `dataexport' "No data archived."
	}

if _rc==0 {
	***	pull the number of archived files noted in the metdata file
		preserve
		qui use wdrdataarchivemetadata, clear
		qui sum panel_number
		local panels=`r(max)'
		restore

	***	just one panel
	if `panels'==1 {
		***	import metadata for one panel and set local
			local panel =`panels'
			preserve
			qui use wdrdataarchivemetadata, clear
		***	export panel number and title of panel, but only if the panel is titled
			local paneltitle "`=panel_title[1]'"
			local paneltitle =subinstr("`paneltitle'",",","",.)
			if "`paneltitle'"!="" {
				file write `dataexport' "Panel `panel'" ","
				file write `dataexport' "`paneltitle'" _n
				}
		***	import the only panel of data, and determine what variables are present
			qui use wdrdataarchivepanel`panel', clear
			qui ds
			local currentvariables `r(varlist)'
		***	write variable names 			
			foreach var of local currentvariables {
				file write `dataexport' "`var'" ","
				}
			file write `dataexport' _n
		***	write variable labels
			foreach var of local currentvariables {
				local current`var'lbl : var label `var'
				local current`var'lbl =subinstr("`current`var'lbl'",",","",.) // remove commas from variable labels so it writes correctly in CSV
				file write `dataexport' "`current`var'lbl'" ","
				}
			file write `dataexport' _n
		***	count the number of observations (rows of data)
			qui count
			local currentrows=`r(N)'
		***	loop over rows and variables to write data to CSV cell by cell
			forvalues row=1/`currentrows' {
				foreach var of local currentvariables {
					local writeable "`=`var'[`row']'"
					local writeable =subinstr("`writeable'",",","",.)
					file write `dataexport' "`writeable'" ","
					}
				file write `dataexport' _n
				}
			file write `dataexport' _n
			restore
		***	erase the panel
			erase "wdrdataarchivepanel`panel'.dta"
			}

***	more than one panel
	if `panels' >1 {
		forvalues panel=1/`panels' {
		***	import metdata, and keep metadata for current panel
			preserve
			qui use wdrdataarchivemetadata, clear
			qui keep if `panel'==panel_number
		***	export panel number and title of panel
			local paneltitle "`=panel_title[1]'"
			local paneltitle =subinstr("`paneltitle'",",","",.)
			file write `dataexport' "Panel `panel'" ","
			file write `dataexport' "`paneltitle'" _n
		***	load relevant panel data
			qui use wdrdataarchivepanel`panel', clear
		***	determine what variables are present
			qui ds
			local currentvariables `r(varlist)'
		***	write the name of the variable
			foreach var of local currentvariables {
				file write `dataexport' "`var'" ","
				}
			file write `dataexport' _n
		***	write the variable labels
			foreach var of local currentvariables {
				local current`var'lbl : var label `var'
				local current`var'lbl =subinstr("`current`var'lbl'",",","",.) // remove commas from variable labels so it writes correctly in CSV
				file write `dataexport' "`current`var'lbl'" ","
				}
			file write `dataexport' _n
		***	count the number of observations
			qui count
			local currentrows=`r(N)'
		***	loop over rows and variables to write data to CSV cell by cell
			forvalues row=1/`currentrows' {
				foreach var of local currentvariables {
				local writeable "`=`var'[`row']'"
					local writeable =subinstr("`writeable'",",","",.)
					file write `dataexport' "`writeable'" ","
					}
					file write `dataexport' _n
				}
			file write `dataexport' _n
			restore
		***	erase the panel
			erase "wdrdataarchivepanel`panel'.dta"
			} 
			} 
			}
		

*** erase psuedo-temporary files
	erase "wdrdataarchivemetadata.dta"

*** close out data export file
	file close `dataexport' 

/*******************************************************************************
RETURN RESULTS IN R
*******************************************************************************/
	return local chapternumber	`chapternumber'
	return local figurenumber 	`figurenumber'
	return local reference		"`reference'"
	return local title			"`formaltitle'"	
	return local subtitle		"`formalsubtitle'"	
	return local source			"`figuresource'"
	return local note			"`figurenote'"
	return local outputpath		"`outputpath'"

/*******************************************************************************
OPTIONALLY DISPLAY RESULTS
*******************************************************************************/
	if "`quietly'"=="" { // only display output if quietly was not selected
		noi di as text		_newline(1) "{hline}"
		noi di as result	"Reference:" 	_col(12) "`reference'"
		noi di as result	"Title:"	_col(12) "`formaltitle'" 
		noi di as result	"Subtitle:"	_col(12) "`formalsubtitle'"		
		noi di as result	"Source:"	_col(12) "`figuresource'"
		noi di as result	"Note:" 	_col(12) "`figurenote'"
		noi di as text 		"{hline}"
		noi di as result 	"Output saved to ${output}`c(dirsep)'" 
		noi di as result 	"Graphics files:" 
		
		foreach figure_type of local figure_types {
			noi di as result _col(12) "${output}`c(dirsep)'`filenamestub'.`figure_type'"
			}
		noi di as result 	"Production files:"
		noi di as result	_col(12) "${output}`c(dirsep)'`filenamestub' meta.dta"
		noi di as result	_col(12) "${output}`c(dirsep)'`filenamestub' data.csv"
		noi di as text		"{hline}" _newline(1)
		}



end

